.PresetDateRangePicker_panel {
  padding: 0 22px 11px
}.PresetDateRangePicker_button {
  position: relative;
  height: 100%;
  text-align: center;
  background: 0 0;
  border: 2px solid #00a699;
  color: #00a699;
  padding: 4px 12px;
  margin-right: 8px;
  font: inherit;
  font-weight: 700;
  line-height: normal;
  overflow: visible;
  box-sizing: border-box;
  cursor: pointer
}.PresetDateRangePicker_button:active {
  outline: 0
}.PresetDateRangePicker_button__selected {
  color: #fff;
  background: #00a699
}.SingleDatePickerInput {
  display: inline-block;
  background-color: #fff
}.SingleDatePickerInput__withBorder {
  border-radius: 2px;
  border: 1px solid #dbdbdb
}.SingleDatePickerInput__rtl {
  direction: rtl
}.SingleDatePickerInput__disabled {
  background-color: #f2f2f2
}.SingleDatePickerInput__block {
  display: block
}.SingleDatePickerInput__showClearDate {
  padding-right: 30px
}.SingleDatePickerInput_clearDate {
  background: 0 0;
  border: 0;
  color: inherit;
  font: inherit;
  line-height: normal;
  overflow: visible;
  cursor: pointer;
  padding: 10px;
  margin: 0 10px 0 5px;
  position: absolute;
  right: 0;
  top: 50%;
  transform: translateY(-50%)
}.SingleDatePickerInput_clearDate__default:focus,
.SingleDatePickerInput_clearDate__default:hover {
  background: #dbdbdb;
  border-radius: 50%
}.SingleDatePickerInput_clearDate__small {
  padding: 6px
}.SingleDatePickerInput_clearDate__hide {
  visibility: hidden
}.SingleDatePickerInput_clearDate_svg {
  fill: #82888a;
  height: 12px;
  width: 15px;
  vertical-align: middle
}.SingleDatePickerInput_clearDate_svg__small {
  height: 9px
}.SingleDatePickerInput_calendarIcon {
  background: 0 0;
  border: 0;
  color: inherit;
  font: inherit;
  line-height: normal;
  overflow: visible;
  cursor: pointer;
  display: inline-block;
  vertical-align: middle;
  padding: 10px;
  margin: 0 5px 0 10px
}.SingleDatePickerInput_calendarIcon_svg {
  fill: #82888a;
  height: 15px;
  width: 14px;
  vertical-align: middle
}.SingleDatePicker {
  position: relative;
  display: inline-block
}.SingleDatePicker__block {
  display: block
}.SingleDatePicker_picker {
  z-index: 1;
  background-color: #fff;
  position: absolute
}.SingleDatePicker_picker__rtl {
  direction: rtl
}.SingleDatePicker_picker__directionLeft {
  left: 0
}.SingleDatePicker_picker__directionRight {
  right: 0
}.SingleDatePicker_picker__portal {
  background-color: rgba(0,0,0,.3);
  position: fixed;
  top: 0;
  left: 0;
  height: 100%;
  width: 100%
}.SingleDatePicker_picker__fullScreenPortal {
  background-color: #fff
}.SingleDatePicker_closeButton {
  background: 0 0;
  border: 0;
  color: inherit;
  font: inherit;
  line-height: normal;
  overflow: visible;
  cursor: pointer;
  position: absolute;
  top: 0;
  right: 0;
  padding: 15px;
  z-index: 2
}.SingleDatePicker_closeButton:focus,
.SingleDatePicker_closeButton:hover {
  color: darken(#cacccd,10%);
  text-decoration: none
}.SingleDatePicker_closeButton_svg {
  height: 15px;
  width: 15px;
  fill: #cacccd
}.DayPickerKeyboardShortcuts_buttonReset {
  background: 0 0;
  border: 0;
  border-radius: 0;
  color: inherit;
  font: inherit;
  line-height: normal;
  overflow: visible;
  padding: 0;
  cursor: pointer;
  font-size: 14px
}.DayPickerKeyboardShortcuts_buttonReset:active {
  outline: 0
}.DayPickerKeyboardShortcuts_show {
  width: 33px;
  height: 26px;
  position: absolute;
  z-index: 2
}.DayPickerKeyboardShortcuts_show::before {
  content: "";
  display: block;
  position: absolute
}.DayPickerKeyboardShortcuts_show__bottomRight {
  bottom: 0;
  right: 0
}.DayPickerKeyboardShortcuts_show__bottomRight::before {
  border-top: 26px solid transparent;
  border-right: 33px solid #00a699;
  bottom: 0;
  right: 0
}.DayPickerKeyboardShortcuts_show__bottomRight:hover::before {
  border-right: 33px solid #008489
}.DayPickerKeyboardShortcuts_show__topRight {
  top: 0;
  right: 0
}.DayPickerKeyboardShortcuts_show__topRight::before {
  border-bottom: 26px solid transparent;
  border-right: 33px solid #00a699;
  top: 0;
  right: 0
}.DayPickerKeyboardShortcuts_show__topRight:hover::before {
  border-right: 33px solid #008489
}.DayPickerKeyboardShortcuts_show__topLeft {
  top: 0;
  left: 0
}.DayPickerKeyboardShortcuts_show__topLeft::before {
  border-bottom: 26px solid transparent;
  border-left: 33px solid #00a699;
  top: 0;
  left: 0
}.DayPickerKeyboardShortcuts_show__topLeft:hover::before {
  border-left: 33px solid #008489
}.DayPickerKeyboardShortcuts_showSpan {
  color: #fff;
  position: absolute
}.DayPickerKeyboardShortcuts_showSpan__bottomRight {
  bottom: 0;
  right: 5px
}.DayPickerKeyboardShortcuts_showSpan__topRight {
  top: 1px;
  right: 5px
}.DayPickerKeyboardShortcuts_showSpan__topLeft {
  top: 1px;
  left: 5px
}.DayPickerKeyboardShortcuts_panel {
  overflow: auto;
  background: #fff;
  border: 1px solid #dbdbdb;
  border-radius: 2px;
  position: absolute;
  top: 0;
  bottom: 0;
  right: 0;
  left: 0;
  z-index: 2;
  padding: 22px;
  margin: 33px;
  text-align: left
}.DayPickerKeyboardShortcuts_title {
  font-size: 16px;
  font-weight: 700;
  margin: 0
}.DayPickerKeyboardShortcuts_list {
  list-style: none;
  padding: 0;
  font-size: 14px
}.DayPickerKeyboardShortcuts_close {
  position: absolute;
  right: 22px;
  top: 22px;
  z-index: 2
}.DayPickerKeyboardShortcuts_close:active {
  outline: 0
}.DayPickerKeyboardShortcuts_closeSvg {
  height: 15px;
  width: 15px;
  fill: #cacccd
}.DayPickerKeyboardShortcuts_closeSvg:focus,
.DayPickerKeyboardShortcuts_closeSvg:hover {
  fill: #82888a
}.CalendarDay {
  box-sizing: border-box;
  cursor: pointer;
  font-size: 14px;
  text-align: center
}.CalendarDay:active {
  outline: 0
}.CalendarDay__defaultCursor {
  cursor: default
}.CalendarDay__default {
  border: 1px solid #e4e7e7;
  color: #484848;
  background: #fff
}.CalendarDay__default:hover {
  background: #e4e7e7;
  border: 1px solid #e4e7e7;
  color: inherit
}.CalendarDay__hovered_offset {
  background: #f4f5f5;
  border: 1px double #e4e7e7;
  color: inherit
}.CalendarDay__outside {
  border: 0;
  background: #fff;
  color: #484848
}.CalendarDay__outside:hover {
  border: 0
}.CalendarDay__blocked_minimum_nights {
  background: #fff;
  border: 1px solid #eceeee;
  color: #cacccd
}.CalendarDay__blocked_minimum_nights:active,
.CalendarDay__blocked_minimum_nights:hover {
  background: #fff;
  color: #cacccd
}.CalendarDay__highlighted_calendar {
  background: #ffe8bc;
  color: #484848
}.CalendarDay__highlighted_calendar:active,
.CalendarDay__highlighted_calendar:hover {
  background: #ffce71;
  color: #484848
}.CalendarDay__selected_span {
  background: #66e2da;
  border: 1px double #33dacd;
  color: #fff
}.CalendarDay__selected_span:active,
.CalendarDay__selected_span:hover {
  background: #33dacd;
  border: 1px double #33dacd;
  color: #fff
}.CalendarDay__selected,
.CalendarDay__selected:active,
.CalendarDay__selected:hover {
  background: #00a699;
  border: 1px double #00a699;
  color: #fff
}.CalendarDay__hovered_span,
.CalendarDay__hovered_span:hover {
  background: #b2f1ec;
  border: 1px double #80e8e0;
  color: #007a87
}.CalendarDay__hovered_span:active {
  background: #80e8e0;
  border: 1px double #80e8e0;
  color: #007a87
}.CalendarDay__blocked_calendar,
.CalendarDay__blocked_calendar:active,
.CalendarDay__blocked_calendar:hover {
  background: #cacccd;
  border: 1px solid #cacccd;
  color: #82888a
}.CalendarDay__blocked_out_of_range,
.CalendarDay__blocked_out_of_range:active,
.CalendarDay__blocked_out_of_range:hover {
  background: #fff;
  border: 1px solid #e4e7e7;
  color: #cacccd
}.CalendarDay__hovered_start_first_possible_end {
  background: #eceeee;
  border: 1px double #eceeee
}.CalendarDay__hovered_start_blocked_min_nights {
  background: #eceeee;
  border: 1px double #e4e7e7
}.CalendarMonth {
  background: #fff;
  text-align: center;
  vertical-align: top;
  -webkit-user-select: none;
  -moz-user-select: none;
  user-select: none
}.CalendarMonth_table {
  border-collapse: collapse;
  border-spacing: 0
}.CalendarMonth_verticalSpacing {
  border-collapse: separate
}.CalendarMonth_caption {
  color: #484848;
  font-size: 18px;
  text-align: center;
  padding-top: 22px;
  padding-bottom: 37px;
  caption-side: initial
}.CalendarMonth_caption__verticalScrollable {
  padding-top: 12px;
  padding-bottom: 7px
}.CalendarMonthGrid {
  background: #fff;
  text-align: left;
  z-index: 0
}.CalendarMonthGrid__animating {
  z-index: 1
}.CalendarMonthGrid__horizontal {
  position: absolute;
  left: 9px
}.CalendarMonthGrid__vertical,
.CalendarMonthGrid__vertical_scrollable {
  margin: 0 auto
}.CalendarMonthGrid_month__horizontal {
  display: inline-block;
  vertical-align: top;
  min-height: 100%
}.CalendarMonthGrid_month__hideForAnimation {
  position: absolute;
  z-index: -1;
  opacity: 0;
  pointer-events: none
}.CalendarMonthGrid_month__hidden {
  visibility: hidden
}.DayPickerNavigation {
  position: relative;
  z-index: 2
}.DayPickerNavigation__horizontal {
  height: 0
}.DayPickerNavigation__verticalScrollable_prevNav {
  z-index: 1
}.DayPickerNavigation__verticalDefault {
  position: absolute;
  width: 100%;
  height: 52px;
  bottom: 0;
  left: 0
}.DayPickerNavigation__verticalScrollableDefault {
  position: relative
}.DayPickerNavigation__bottom {
  height: auto
}.DayPickerNavigation__bottomDefault {
  -webkit-box-pack: justify;
  -ms-flex-pack: justify;
  display: flex;
  justify-content: space-between
}.DayPickerNavigation_button {
  cursor: pointer;
  -webkit-user-select: none;
  -moz-user-select: none;
  user-select: none;
  border: 0;
  padding: 0;
  margin: 0
}.DayPickerNavigation_button__default {
  border: 1px solid #e4e7e7;
  background-color: #fff;
  color: #757575
}.DayPickerNavigation_button__default:focus,
.DayPickerNavigation_button__default:hover {
  border: 1px solid #c4c4c4
}.DayPickerNavigation_button__default:active {
  background: #f2f2f2
}.DayPickerNavigation_button__disabled {
  cursor: default;
  border: 1px solid #f2f2f2
}.DayPickerNavigation_button__disabled:focus,
.DayPickerNavigation_button__disabled:hover {
  border: 1px solid #f2f2f2
}.DayPickerNavigation_button__disabled:active {
  background: 0 0
}.DayPickerNavigation_button__horizontalDefault {
  position: absolute;
  top: 18px;
  line-height: .78;
  border-radius: 3px;
  padding: 6px 9px
}.DayPickerNavigation_bottomButton__horizontalDefault {
  position: static;
  margin: -10px 22px 30px
}.DayPickerNavigation_leftButton__horizontalDefault {
  left: 22px
}.DayPickerNavigation_rightButton__horizontalDefault {
  right: 22px
}.DayPickerNavigation_button__verticalDefault {
  padding: 5px;
  background: #fff;
  box-shadow: 0 0 5px 2px rgba(0,0,0,.1);
  position: relative;
  display: inline-block;
  text-align: center;
  height: 100%;
  width: 50%
}.DayPickerNavigation_nextButton__verticalDefault {
  border-left: 0
}.DayPickerNavigation_nextButton__verticalScrollableDefault,
.DayPickerNavigation_prevButton__verticalScrollableDefault {
  width: 100%
}.DayPickerNavigation_svg__horizontal {
  height: 19px;
  width: 19px;
  fill: #82888a;
  display: block
}.DayPickerNavigation_svg__vertical {
  height: 42px;
  width: 42px;
  fill: #484848
}.DayPickerNavigation_svg__disabled {
  fill: #f2f2f2
}.DayPicker {
  background: #fff;
  position: relative;
  text-align: left
}.DayPicker__horizontal {
  background: #fff
}.DayPicker__verticalScrollable {
  height: 100%
}.DayPicker__hidden {
  visibility: hidden
}.DayPicker__withBorder {
  box-shadow: 0 2px 6px rgba(0,0,0,.05),0 0 0 1px rgba(0,0,0,.07);
  border-radius: 3px
}.DayPicker_portal__horizontal {
  box-shadow: none;
  position: absolute;
  left: 50%;
  top: 50%
}.DayPicker_portal__vertical {
  position: initial
}.DayPicker_focusRegion {
  outline: 0
}.DayPicker_calendarInfo__horizontal,
.DayPicker_wrapper__horizontal {
  display: inline-block;
  vertical-align: top
}.DayPicker_weekHeaders {
  position: relative
}.DayPicker_weekHeaders__horizontal {
  margin-left: 9px
}.DayPicker_weekHeader {
  color: #757575;
  position: absolute;
  top: 62px;
  z-index: 2;
  text-align: left
}.DayPicker_weekHeader__vertical {
  left: 50%
}.DayPicker_weekHeader__verticalScrollable {
  top: 0;
  display: table-row;
  border-bottom: 1px solid #dbdbdb;
  background: #fff;
  margin-left: 0;
  left: 0;
  width: 100%;
  text-align: center
}.DayPicker_weekHeader_ul {
  list-style: none;
  margin: 1px 0;
  padding-left: 0;
  padding-right: 0;
  font-size: 14px
}.DayPicker_weekHeader_li {
  display: inline-block;
  text-align: center
}.DayPicker_transitionContainer {
  position: relative;
  overflow: hidden;
  border-radius: 3px
}.DayPicker_transitionContainer__horizontal {
  transition: height .2s ease-in-out
}.DayPicker_transitionContainer__vertical {
  width: 100%
}.DayPicker_transitionContainer__verticalScrollable {
  padding-top: 20px;
  height: 100%;
  position: absolute;
  top: 0;
  bottom: 0;
  right: 0;
  left: 0;
  overflow-y: scroll
}.DateInput {
  margin: 0;
  padding: 0;
  background: #fff;
  position: relative;
  display: inline-block;
  width: 130px;
  vertical-align: middle
}.DateInput__small {
  width: 97px
}.DateInput__block {
  width: 100%
}.DateInput__disabled {
  background: #f2f2f2;
  color: #dbdbdb
}.DateInput_input {
  font-weight: 200;
  font-size: 19px;
  line-height: 24px;
  color: #484848;
  background-color: #fff;
  width: 100%;
  padding: 11px 11px 9px;
  border: 0;
  border-top: 0;
  border-right: 0;
  border-bottom: 2px solid transparent;
  border-left: 0;
  border-radius: 0
}.DateInput_input__small {
  font-size: 15px;
  line-height: 18px;
  letter-spacing: .2px;
  padding: 7px 7px 5px
}.DateInput_input__regular {
  font-weight: auto
}.DateInput_input__readOnly {
  -webkit-user-select: none;
  -moz-user-select: none;
  user-select: none
}.DateInput_input__focused {
  outline: 0;
  background: #fff;
  border: 0;
  border-top: 0;
  border-right: 0;
  border-bottom: 2px solid #008489;
  border-left: 0
}.DateInput_input__disabled {
  background: #f2f2f2;
  font-style: italic
}.DateInput_screenReaderMessage {
  border: 0;
  clip: rect(0,0,0,0);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px
}.DateInput_fang {
  position: absolute;
  width: 20px;
  height: 10px;
  left: 22px;
  z-index: 2
}.DateInput_fangShape {
  fill: #fff
}.DateInput_fangStroke {
  stroke: #dbdbdb;
  fill: transparent
}.DateRangePickerInput {
  background-color: #fff;
  display: inline-block
}.DateRangePickerInput__disabled {
  background: #f2f2f2
}.DateRangePickerInput__withBorder {
  border-radius: 2px;
  border: 1px solid #dbdbdb
}.DateRangePickerInput__rtl {
  direction: rtl
}.DateRangePickerInput__block {
  display: block
}.DateRangePickerInput__showClearDates {
  padding-right: 30px
}.DateRangePickerInput_arrow {
  display: inline-block;
  vertical-align: middle;
  color: #484848
}.DateRangePickerInput_arrow_svg {
  vertical-align: middle;
  fill: #484848;
  height: 24px;
  width: 24px
}.DateRangePickerInput_clearDates {
  background: 0 0;
  border: 0;
  color: inherit;
  font: inherit;
  line-height: normal;
  overflow: visible;
  cursor: pointer;
  padding: 10px;
  margin: 0 10px 0 5px;
  position: absolute;
  right: 0;
  top: 50%;
  transform: translateY(-50%)
}.DateRangePickerInput_clearDates__small {
  padding: 6px
}.DateRangePickerInput_clearDates_default:focus,
.DateRangePickerInput_clearDates_default:hover {
  background: #dbdbdb;
  border-radius: 50%
}.DateRangePickerInput_clearDates__hide {
  visibility: hidden
}.DateRangePickerInput_clearDates_svg {
  fill: #82888a;
  height: 12px;
  width: 15px;
  vertical-align: middle
}.DateRangePickerInput_clearDates_svg__small {
  height: 9px
}.DateRangePickerInput_calendarIcon {
  background: 0 0;
  border: 0;
  color: inherit;
  font: inherit;
  line-height: normal;
  overflow: visible;
  cursor: pointer;
  display: inline-block;
  vertical-align: middle;
  padding: 10px;
  margin: 0 5px 0 10px
}.DateRangePickerInput_calendarIcon_svg {
  fill: #82888a;
  height: 15px;
  width: 14px;
  vertical-align: middle
}.DateRangePicker {
  position: relative;
  display: inline-block
}.DateRangePicker__block {
  display: block
}.DateRangePicker_picker {
  z-index: 1;
  background-color: #fff;
  position: absolute
}.DateRangePicker_picker__rtl {
  direction: rtl
}.DateRangePicker_picker__directionLeft {
  left: 0
}.DateRangePicker_picker__directionRight {
  right: 0
}.DateRangePicker_picker__portal {
  background-color: rgba(0,0,0,.3);
  position: fixed;
  top: 0;
  left: 0;
  height: 100%;
  width: 100%
}.DateRangePicker_picker__fullScreenPortal {
  background-color: #fff
}.DateRangePicker_closeButton {
  background: 0 0;
  border: 0;
  color: inherit;
  font: inherit;
  line-height: normal;
  overflow: visible;
  cursor: pointer;
  position: absolute;
  top: 0;
  right: 0;
  padding: 15px;
  z-index: 2
}.DateRangePicker_closeButton:focus,
.DateRangePicker_closeButton:hover {
  color: darken(#cacccd,10%);
  text-decoration: none
}.DateRangePicker_closeButton_svg {
  height: 15px;
  width: 15px;
  fill: #cacccd
}:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px;--wp-block-synced-color: #7a00df;--wp-block-synced-color--rgb: 122, 0, 223;--wp-bound-block-color: var(--wp-block-synced-color)}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.tour-kit-frame{visibility:hidden}.tour-kit-frame.is-visible{visibility:visible}.tour-kit-frame__container{border-radius:2px;bottom:44px;display:inline;right:16px;position:fixed;z-index:9999;cursor:default;box-shadow:0 0 3px 0 rgba(0,0,0,.25);background:var(--studio-white)}.tour-kit-overlay{position:fixed;width:100vw;height:100vh;top:0;right:0;background:#000;opacity:0}.tour-kit-overlay.is-visible{opacity:.5}.tour-kit-spotlight.is-visible{position:fixed;overflow:hidden;outline:99999px solid rgba(0,0,0,.5);z-index:1}.tour-kit-frame__arrow{visibility:hidden}.tour-kit-frame__arrow,.tour-kit-frame__arrow::before{position:absolute;width:12px;height:12px;background:inherit;z-index:-1}.tour-kit-frame__arrow::before{visibility:visible;content:"";transform:rotate(-45deg)}.tour-kit-frame__container[data-popper-placement^=top]>.tour-kit-frame__arrow{bottom:-6px}.tour-kit-frame__container[data-popper-placement^=top]>.tour-kit-frame__arrow::before{box-shadow:-1px 1px 2px -1px rgba(0,0,0,.25)}.tour-kit-frame__container[data-popper-placement^=bottom]>.tour-kit-frame__arrow{top:-6px}.tour-kit-frame__container[data-popper-placement^=bottom]>.tour-kit-frame__arrow::before{box-shadow:1px -1px 2px -1px rgba(0,0,0,.25)}.tour-kit-frame__container[data-popper-placement^=left]>.tour-kit-frame__arrow{left:-6px}.tour-kit-frame__container[data-popper-placement^=left]>.tour-kit-frame__arrow::before{box-shadow:-1px -1px 2px -1px rgba(0,0,0,.25)}.tour-kit-frame__container[data-popper-placement^=right]>.tour-kit-frame__arrow{right:-6px}.tour-kit-frame__container[data-popper-placement^=right]>.tour-kit-frame__arrow::before{box-shadow:1px 1px 2px -1px rgba(0,0,0,.25)}.woocommerce-abbreviated-card a{display:flex;flex-direction:row;border-bottom:1px solid #e0e0e0;text-decoration:none}.woocommerce-abbreviated-card__icon{display:flex;align-items:center;padding:16px 24px}.woocommerce-abbreviated-card__icon svg{fill:var(--wp-admin-theme-color)}.woocommerce-calendar{width:100%;background-color:#f0f0f0;border-top:1px solid #ccc;height:396px}.woocommerce-calendar.is-mobile{height:100%}.woocommerce-calendar__react-dates{width:100%;overflow-x:hidden}.woocommerce-calendar__react-dates .DayPicker{margin:0 auto}.woocommerce-calendar__react-dates .CalendarMonth_table{margin-top:10px}.woocommerce-calendar__react-dates .CalendarDay__selected_span{background:var(--wp-admin-theme-color);border:1px solid #ccc}.woocommerce-calendar__react-dates .CalendarDay__selected_span:hover{background:var(--wp-admin-theme-color-darker-10);border:1px solid #f0f0f0}.woocommerce-calendar__react-dates .CalendarDay__selected{background:var(--wp-admin-theme-color-darker-20);border:1px solid #ccc}.woocommerce-calendar__react-dates .CalendarDay__selected:hover{background:var(--wp-admin-theme-color-darker-10);border:1px solid #f0f0f0}.woocommerce-calendar__react-dates .CalendarDay__hovered_span{background:var(--wp-admin-theme-color-darker-10);border:1px solid #f0f0f0;color:#fff}.woocommerce-calendar__react-dates .CalendarDay__hovered_span:hover{color:#fff;background:var(--wp-admin-theme-color)}.woocommerce-calendar__react-dates .CalendarDay__blocked_out_of_range{color:#ccc}.woocommerce-calendar__react-dates .DayPicker_transitionContainer,.woocommerce-calendar__react-dates .CalendarMonthGrid,.woocommerce-calendar__react-dates .CalendarMonth,.woocommerce-calendar__react-dates .DayPicker{background-color:#f0f0f0}.woocommerce-calendar__react-dates .DayPicker_weekHeader_li{color:#757575}.woocommerce-calendar__react-dates .DayPickerNavigation_button:focus{outline:2px solid #bfe7f3}.woocommerce-calendar__react-dates.is-core-datepicker .components-datetime__date{padding-right:0}.woocommerce-calendar__react-dates.is-core-datepicker .CalendarDay__default{background-color:rgba(0,0,0,0)}.woocommerce-calendar__react-dates.is-core-datepicker .CalendarDay__selected{background:#5007aa;border:none}.woocommerce-calendar__inputs{padding:1em;width:100%;max-width:500px;display:grid;grid-template-columns:43% 14% 43%;margin:0 auto}.woocommerce-calendar__inputs .components-base-control{margin:0}.woocommerce-calendar__inputs-to{display:flex;align-items:center;justify-content:center;grid-column-start:2}.woocommerce-calendar__input{position:relative}.woocommerce-calendar__input .calendar-icon{position:absolute;top:50%;transform:translateY(-50%);right:7px}.woocommerce-calendar__input .calendar-icon path{fill:#757575}.woocommerce-calendar__input:first-child{grid-column-start:1}.woocommerce-calendar__input:last-child{grid-column-start:3}.woocommerce-calendar__input.is-empty .calendar-icon path{fill:#757575}.woocommerce-calendar__input.is-error .calendar-icon path{fill:#d94f4f}.woocommerce-calendar__input.is-error .woocommerce-calendar__input-text{border:1px solid #d94f4f;box-shadow:inset 0 0 8px #d94f4f}.woocommerce-calendar__input.is-error .woocommerce-calendar__input-text:focus{box-shadow:inset 0 0 8px #d94f4f,0 0 6px rgba(30,140,190,.8)}.woocommerce-calendar__input .woocommerce-calendar__input-text{color:#757575;border-radius:3px;padding:0 30px 0 10px;width:100%;font-size:13px;font-size:0.8125rem;min-height:40px}.woocommerce-calendar__input .woocommerce-calendar__input-text::-moz-placeholder{color:#757575}.woocommerce-calendar__input .woocommerce-calendar__input-text::placeholder{color:#757575}.woocommerce-filters-date__content.is-mobile .woocommerce-calendar__input-error .components-popover__content{height:initial}.woocommerce-calendar__input-error{display:none}.is-error .woocommerce-calendar__input-text:focus+span .woocommerce-calendar__input-error{display:block;right:50% !important;position:absolute;top:auto !important}.woocommerce-calendar__input-error .components-popover__content{background-color:#757575;color:#fff;padding:.5em;border:none}.woocommerce-calendar__input-error.components-popover .components-popover__content{min-width:100px;width:100px;text-align:center}.woocommerce-calendar__input-error.components-popover:not(.no-arrow):not(.is-mobile).is-bottom::before{border-bottom-color:#757575;z-index:1;top:-6px}.woocommerce-calendar__input-error.components-popover:not(.no-arrow):not(.is-mobile).is-top::after{border-top-color:#757575;z-index:1;top:0}.woocommerce-calendar__date-picker-title{font-size:12px;font-size:0.75rem;font-weight:100;text-transform:uppercase;text-align:center;color:#757575;width:100%;margin:0;padding:1em;background-color:#fff}.woocommerce-chart{margin-top:-16px;margin-bottom:24px;background:#fff;border:1px solid #e2e4e7;border-top:0}@media(max-width: 782px){.woocommerce-chart{margin-right:-16px;margin-left:-16px;margin-bottom:12px;border-right:none;border-left:none;width:auto}}.woocommerce-chart .woocommerce-chart__header{min-height:50px;border-bottom:1px solid #e2e4e7;display:flex;flex-flow:row wrap;justify-content:space-between;align-items:center;width:100%}.woocommerce-chart .woocommerce-chart__header .woocommerce-chart__title{margin-right:24px;margin-left:16px}.woocommerce-chart .woocommerce-chart__body{display:flex;flex-direction:row;justify-content:flex-start;align-items:flex-start;width:100%}.woocommerce-chart .woocommerce-chart__body.woocommerce-chart__body-column{flex-direction:column}.woocommerce-chart .woocommerce-chart__footer{width:100%}.woocommerce-chart-placeholder{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);padding:0;width:100%;display:flex;align-items:center;justify-content:center}.woocommerce-chart-placeholder::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-chart-placeholder{animation:none}}.woocommerce-chart-placeholder .components-spinner{margin:0}.woocommerce-chart__interval-select{align-items:flex-start;border-left:1px solid #e2e4e7;display:flex;flex-direction:column;justify-content:center;margin:0 auto 0 0;min-height:50px;padding:0 16px}@media(max-width: 960px){.woocommerce-chart__interval-select{width:100%;order:1;margin-right:0;padding-right:8px;border-left:0;min-height:0}}#wpbody .woocommerce-chart__interval-select .components-select-control__input{font-size:13px;font-size:0.8125rem;border:0;box-shadow:none}#wpbody .woocommerce-chart__interval-select .components-select-control__input .components-input-control__backdrop{display:none}#wpbody .woocommerce-chart__interval-select .components-select-control__input:not(:disabled):not([aria-disabled=true]):focus{background-color:#fff;color:#1e1e1e;box-shadow:inset 0 0 0 1px #757575,inset 0 0 0 2px #fff;outline:2px solid rgba(0,0,0,0);outline-offset:-2px}#wpbody .woocommerce-chart__interval-select .components-select-control__input:not(:disabled):not([aria-disabled=true]):focus~.components-input-control__backdrop{display:block}#wpbody .woocommerce-chart__interval-select .components-select-control__input~.components-input-control__backdrop{display:none}.woocommerce-chart__types{align-items:center;display:flex;padding:0 8px;white-space:nowrap}.woocommerce-chart__type-button{background:rgba(0,0,0,0) !important}.woocommerce-chart__type-button.components-button{color:#e2e4e7;display:inline-flex;padding:8px}.woocommerce-chart__type-button.components-button.woocommerce-chart__type-button-selected{color:#757575}@media(max-width: 960px){.woocommerce-summary+.woocommerce-chart .woocommerce-chart__title{display:none}.woocommerce-summary+.woocommerce-chart .woocommerce-chart__interval-select{width:auto;order:0;margin-top:0}}.woocommerce-legend.has-total{padding-bottom:50px;position:relative}.woocommerce-legend.woocommerce-legend__direction-column{border-left:1px solid #ccc;min-width:320px}.woocommerce-chart__footer .woocommerce-legend.woocommerce-legend__direction-column{border-left:none}.woocommerce-legend.woocommerce-legend__direction-row{flex-grow:1;flex-direction:row}.woocommerce-legend__list{color:#24292d;display:flex;height:100%;margin:0;flex-flow:row wrap;flex-wrap:wrap}.woocommerce-legend__direction-column .woocommerce-legend__list{flex-direction:column;height:300px;overflow:auto}.woocommerce-chart__footer .woocommerce-legend__direction-column .woocommerce-legend__list{border-top:1px solid #ccc;height:100%;max-height:none;min-height:none}.has-total.woocommerce-legend__direction-column .woocommerce-legend__list{height:250px}.woocommerce-chart__footer .has-total.woocommerce-legend__direction-column .woocommerce-legend__list{height:auto;max-height:220px;min-height:none}.woocommerce-legend__direction-row .woocommerce-legend__list{flex-direction:row}.woocommerce-legend__item>button{display:flex;justify-content:center;align-items:center;background-color:#fff;color:#757575;cursor:pointer;display:inline-flex;flex-direction:row;flex-wrap:nowrap;justify-content:space-between;width:100%;border:none;padding:0}.woocommerce-legend__item>button .woocommerce-legend__item-container{display:flex;flex-direction:row;flex-wrap:nowrap;position:relative;padding:3px 24px 3px 0;font-size:13px;-webkit-user-select:none;-moz-user-select:none;user-select:none;width:100%}.woocommerce-legend__item>button .woocommerce-legend__item-container:hover input~.woocommerce-legend__item-checkmark{background-color:#e0e0e0}.woocommerce-legend__item>button .woocommerce-legend__item-container .woocommerce-legend__item-checkmark{border:1px solid #ccc;position:absolute;top:4px;right:0;height:16px;width:16px;background-color:#fff}.woocommerce-legend__item>button .woocommerce-legend__item-container .woocommerce-legend__item-checkmark::after{content:"";position:absolute;display:none}.woocommerce-legend__item>button .woocommerce-legend__item-container .woocommerce-legend__item-checkmark.woocommerce-legend__item-checkmark-checked{background-color:currentColor;border-color:currentColor}.woocommerce-legend__item>button .woocommerce-legend__item-container .woocommerce-legend__item-checkmark.woocommerce-legend__item-checkmark-checked::after{display:block;right:5px;top:2px;width:3px;height:6px;border:solid #fff;border-width:0 0 2px 2px;transform:rotate(-45deg);}.rtl .woocommerce-legend__item>button .woocommerce-legend__item-container .woocommerce-legend__item-checkmark.woocommerce-legend__item-checkmark-checked::after{transform:rotate(45deg) scaleX(-1)}.woocommerce-legend__item>button .woocommerce-legend__item-container .woocommerce-legend__item-total{margin-right:auto;font-weight:bold}.woocommerce-legend__item>button:focus{outline:none}.woocommerce-legend__item>button:focus .woocommerce-legend__item-container .woocommerce-legend__item-checkmark{outline:2px solid #ccc}.woocommerce-legend__item>button:hover{background-color:#f0f0f0}.woocommerce-legend__direction-column .woocommerce-legend__item{margin:0;padding:0}.woocommerce-legend__direction-column .woocommerce-legend__item>button{min-height:36px;padding:0 17px;text-align:right}.woocommerce-legend__direction-column .woocommerce-legend__item:first-child{margin-top:12px}.woocommerce-legend__direction-column .woocommerce-legend__item:last-child::after{content:"";display:block;height:12px;width:100%}.woocommerce-legend__direction-row .woocommerce-legend__item{padding:0;margin:0;flex:1 0 20%;max-width:338px}.woocommerce-legend__direction-row .woocommerce-legend__item>button{padding:0 17px}.woocommerce-legend__direction-row .woocommerce-legend__item>button .woocommerce-legend__item-container{height:50px;align-items:center}.woocommerce-legend__direction-row .woocommerce-legend__item>button .woocommerce-legend__item-container .woocommerce-legend__item-checkmark{top:17px}.woocommerce-legend__direction-row .woocommerce-legend__item>button .woocommerce-legend__item-container .woocommerce-legend__item-title{margin-left:17px}.woocommerce-legend__total{align-items:center;background:#fff;border-top:1px solid #ccc;bottom:0;color:#757575;display:flex;height:50px;justify-content:center;right:0;position:absolute;left:0;text-transform:uppercase}.woocommerce-legend__total::before{background:linear-gradient(-180deg, rgba(0, 0, 0, 0), rgba(0, 0, 0, 0.2));bottom:100%;content:"";height:20px;right:0;opacity:0;pointer-events:none;position:absolute;left:0;transition:opacity .3s}.is-scrollable .woocommerce-legend__total::before{opacity:1}.woocommerce-chart__body-row .d3-chart__container{width:calc(100% - 320px)}.d3-chart__container{position:relative;width:100%}.d3-chart__container svg{overflow:visible}.d3-chart__container .d3-chart__empty-message{align-items:center;bottom:0;color:#757575;display:flex;font-size:18px;font-size:1.125rem;font-weight:bold;justify-content:center;right:0;line-height:1.5;margin:0 auto;max-width:50%;padding-bottom:48px;pointer-events:none;position:absolute;left:0;top:0;text-align:center}@media(max-width: 782px){.d3-chart__container .d3-chart__empty-message{font-size:13px;font-size:0.8125rem}}.d3-chart__container .d3-chart__tooltip{border:1px solid #ccc;position:absolute;display:flex;min-width:324px;height:auto;background-color:#fff;text-align:right;padding:17px;box-shadow:0 3px 20px 0 rgba(18,24,30,.1),0 1px 3px 0 rgba(18,24,30,.1);flex-direction:column;flex-wrap:nowrap;justify-content:flex-start;pointer-events:none;visibility:hidden;z-index:1}@media(max-width: 600px){.d3-chart__container .d3-chart__tooltip{min-width:auto;width:calc(100% - 48px)}}.d3-chart__container .d3-chart__tooltip h4{text-align:right;line-height:18px;width:100%;text-transform:uppercase;font-size:11px;color:#757575;margin-top:0}.d3-chart__container .d3-chart__tooltip ul{list-style:none;margin-bottom:2px;margin-top:2px;font-size:14px}.d3-chart__container .d3-chart__tooltip ul li{display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:flex-start;align-items:center}.d3-chart__container .d3-chart__tooltip ul li.key-row{display:flex;flex-direction:row;justify-content:space-between;width:100%}.d3-chart__container .d3-chart__tooltip ul li.key-row .key-container{width:100%;min-width:100px}.d3-chart__container .d3-chart__tooltip ul li.key-row .key-container .key-color{display:inline-block;width:16px;height:16px;margin-left:8px}.d3-chart__container .d3-chart__tooltip ul li.key-row .key-container .key-key{margin-left:6px}.d3-chart__container .d3-chart__tooltip ul li.key-row .key-value{font-weight:600}.d3-chart__container .bargrouprect{shape-rendering:crispEdges}.d3-chart__container .grid .tick line{stroke:#f0f0f0;stroke-width:1;shape-rendering:crispEdges}.d3-chart__container .grid .tick:first-child line{stroke:#757575}.d3-chart__container .grid.with-positive-ticks .tick:last-child line{opacity:0}.d3-chart__container .tick{padding-top:10px;stroke-width:1}.d3-chart__container .y-axis{text-anchor:start}.d3-chart__container .y-axis.ticktext{fill:#757575}.d3-chart__container .y-axis .tick text,.d3-chart__container .axis-month .tick text{font-size:10px}.d3-chart__container .focus-grid line{stroke:rgba(0,0,0,.1);stroke-width:1px}.d3-chart__container .barfocus{fill:rgba(0,0,0,.1)}.d3-base{background:rgba(0,0,0,0);overflow-x:auto;overflow-y:hidden;position:relative;width:100%;height:100%}.components-button.woocommerce-dropdown-button{background-color:#fff;position:relative;border:1px solid #757575;color:#1e1e1e;border-radius:4px;padding:0 0 0 40px;width:100%;height:auto}.components-button.woocommerce-dropdown-button::after{content:"";background:#1e1e1e;-webkit-mask:url("data:image/svg+xml;charset=US-ASCII,%3Csvg%20width%3D%2220%22%20height%3D%2220%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%3Cpath%20d%3D%22M5%206l5%205%205-5%202%201-7%207-7-7%202-1z%22%20%2F%3E%3C%2Fsvg%3E") no-repeat right 0 top 55%;mask:url("data:image/svg+xml;charset=US-ASCII,%3Csvg%20width%3D%2220%22%20height%3D%2220%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%3Cpath%20d%3D%22M5%206l5%205%205-5%202%201-7%207-7-7%202-1z%22%20%2F%3E%3C%2Fsvg%3E") no-repeat right 0 top 55%;position:absolute;left:14px;width:32px;height:48px}.components-button.woocommerce-dropdown-button.is-open::after{transform:translateX(-12px) translateY(2px) rotate(-180deg)}.components-button.woocommerce-dropdown-button:hover,.components-button.woocommerce-dropdown-button:active,.components-button.woocommerce-dropdown-button.is-open{color:var(--wp-admin-theme-color)}.components-button.woocommerce-dropdown-button:hover::after,.components-button.woocommerce-dropdown-button:active::after,.components-button.woocommerce-dropdown-button.is-open::after{background:var(--wp-admin-theme-color)}.components-button.woocommerce-dropdown-button.is-multi-line .woocommerce-dropdown-button__labels{flex-direction:column}.components-button.woocommerce-dropdown-button:not(:focus):not(.is-open){border-color:#757575}.woocommerce-dropdown-button__labels{text-align:right;padding:8px 12px;min-height:48px;display:flex;align-items:center;width:100%;justify-content:space-around}@media(max-width: 400px){.woocommerce-dropdown-button__labels{min-height:46px}}.woocommerce-dropdown-button__labels span{width:100%;text-align:right}.woocommerce-dropdown-button__labels span:last-child{font-size:12px;font-size:0.75rem;margin:0}.woocommerce-dropdown-button__labels span:first-child{font-size:13px;font-size:0.8125rem;font-weight:600}@media(max-width: 400px){.woocommerce-dropdown-button__labels span:last-child{font-size:10px;font-size:0.625rem}.woocommerce-dropdown-button__labels span:first-child{font-size:12px;font-size:0.75rem}}.woocommerce-ellipsis-menu{text-align:center}.woocommerce-ellipsis-menu .woocommerce-ellipsis-menu__toggle{justify-content:center;vertical-align:middle;width:24px;padding:0}.woocommerce-ellipsis-menu .woocommerce-ellipsis-menu__toggle .gridicon{transform:rotate(-90deg)}.woocommerce-ellipsis-menu__popover{text-align:right}.woocommerce-ellipsis-menu__popover:not(.is-mobile)::before,.woocommerce-ellipsis-menu__popover:not(.is-mobile)::after{margin-right:-16px}.woocommerce-ellipsis-menu__popover .components-popover__content{width:182px;padding:2px}.woocommerce-ellipsis-menu__popover .woocommerce-ellipsis-menu__content{width:100%}.woocommerce-ellipsis-menu__popover .woocommerce-ellipsis-menu__content .components-button{justify-content:center;width:100%}.woocommerce-ellipsis-menu__popover .woocommerce-ellipsis-menu__title,.woocommerce-ellipsis-menu__popover .woocommerce-ellipsis-menu__item{padding:4px 12px}.woocommerce-ellipsis-menu__popover .woocommerce-ellipsis-menu__item{cursor:pointer;color:#757575}.woocommerce-ellipsis-menu__popover .woocommerce-ellipsis-menu__item:focus{box-shadow:inset 0 0 0 1px #6c7781,inset 0 0 0 2px #fff;outline:2px solid rgba(0,0,0,0);outline-offset:-2px}.woocommerce-ellipsis-menu__popover .woocommerce-ellipsis-menu__item .components-form-toggle{margin-left:8px}.woocommerce-ellipsis-menu__popover .components-base-control__label,.woocommerce-ellipsis-menu__popover .woocommerce-ellipsis-menu__title{color:#1e1e1e;padding-top:8px;padding-bottom:8px;font-size:15px;font-size:0.9375rem;margin-bottom:4px}.woocommerce-ellipsis-menu__popover .components-toggle-control .components-base-control__field{margin:4px 0}.woocommerce-ellipsis-menu__popover .components-base-control{margin:0}.woocommerce-empty-content{margin-bottom:16px;text-align:center}.woocommerce-empty-content .woocommerce-empty-content__illustration{max-width:100%}.woocommerce-empty-content .woocommerce-empty-content__actions .components-button+.components-button{margin-right:16px}.woocommerce-experimental-select-control__combo-box-wrapper{cursor:text;border:1px solid #a7aaad;border-radius:2px;background:#fff;position:relative;display:flex;align-items:center;margin-bottom:4px;min-height:36px;box-sizing:border-box}.woocommerce-experimental-select-control__combo-box-wrapper--disabled{background-color:#f0f0f0;border-color:#ccc;opacity:1}.woocommerce-experimental-select-control__combo-box-wrapper--disabled .woocommerce-experimental-select-control__items-wrapper{opacity:.5}.woocommerce-experimental-select-control__combo-box-wrapper--disabled .woocommerce-experimental-select-control__suffix{fill:#ccc}.woocommerce-experimental-select-control__items-wrapper{display:flex;flex-grow:1;align-items:center;padding:2px 8px}.woocommerce-experimental-select-control__items-wrapper>*{display:inline-flex}.woocommerce-experimental-select-control__combox-box{flex-grow:1;align-items:center;flex-basis:120px;display:inline-flex}.woocommerce-experimental-select-control__combox-box input{width:100%;margin-top:2px;margin-bottom:2px;font-size:13px}.woocommerce-experimental-select-control__suffix{align-self:stretch}.woocommerce-experimental-select-control__combox-box-toggle-button{all:unset;position:absolute;left:6px;top:50%;transform:translateY(-50%)}.woocommerce-experimental-select-control__combox-box-toggle-button>svg{margin-top:4px}.woocommerce-experimental-select-control:not(.is-focused) .woocommerce-experimental-select-control__combox-box-toggle-button{pointer-events:none}.woocommerce-experimental-select-control__menu{position:absolute;width:100%;top:100%;right:-1px;margin-top:8px;box-sizing:border-box}.components-popover.woocommerce-experimental-select-control__popover-menu{background:#fff;border-radius:3px;display:none}.components-popover.woocommerce-experimental-select-control__popover-menu.is-open.has-results{display:block}.woocommerce-experimental-select-control__popover-menu .components-popover__content{overflow:hidden}.woocommerce-experimental-select-control__popover-menu-container{margin:0;width:100%;max-height:300px;overflow-y:scroll}.woocommerce-experimental-select-control__popover-menu-container>.category-field-dropdown__item:not(:first-child) .category-field-dropdown__item-content{border-top:1px solid #e0e0e0}.woocommerce-experimental-select-control__menu-item{padding:12px;margin:0}.woocommerce-experimental-select-control__menu-item .components-base-control__field{margin-bottom:0}.woocommerce-experimental-select-control__selected-items{flex-wrap:wrap}.woocommerce-experimental-select-control__selected-items.is-read-only{font-size:13px;color:#1e1e1e;font-family:var(--wp--preset--font-family--system-font)}.woocommerce-experimental-select-control__selected-item{margin-left:4px;margin-top:2px;margin-bottom:2px;cursor:default;display:inline-flex}.woocommerce-experimental-select-control__selected-item .woocommerce-tag{margin:0}.woocommerce-experimental-select-control__selected-item .woocommerce-tag .woocommerce-tag__remove{cursor:default}.woocommerce-experimental-select-control__suffix-icon{display:flex;align-items:center;height:100%;padding-left:8px}.woocommerce-experimental-select-control__suffix-icon .components-spinner{margin:0}.woocommerce-experimental-select-control{position:relative}.woocommerce-experimental-select-control.is-focused .woocommerce-experimental-select-control__combo-box-wrapper{box-shadow:0 0 0 1px var(--wp-admin-theme-color);border-color:var(--wp-admin-theme-color)}.woocommerce-experimental-select-control.is-read-only.is-multiple.has-selected-items .woocommerce-experimental-select-control__combo-box-wrapper{cursor:default}.woocommerce-experimental-select-control.is-read-only.is-multiple.has-selected-items .woocommerce-experimental-select-control__input{opacity:0;width:0;height:0}.woocommerce-experimental-select-control__label{display:inline-block;margin-bottom:8px}.woocommerce-experimental-select-control .woocommerce-experimental-select-control__input{border:0;box-shadow:none}.woocommerce-experimental-select-control .woocommerce-experimental-select-control__input:focus{outline:none}.woocommerce-filters-advanced{margin:24px 0}.woocommerce-filters-advanced .components-card__body{background-color:#f0f0f0;overflow:initial}.woocommerce-filters-advanced .components-card__body.is-size-small:hover,.woocommerce-filters-advanced .components-card__body ul li:hover{background-color:#e0e0e0}.woocommerce-filters-advanced .components-select-control .components-input-control__container .components-select-control__input{height:38px;padding:0 8px 0 0;margin:0}.woocommerce-filters-advanced .components-card__header .components-base-control__field{margin-bottom:0}.woocommerce-filters-advanced .components-card__header .components-base-control{display:inline-block}@media(max-width: 782px){.woocommerce-filters-advanced{margin:16px 0;border:1px solid #ccc}}@media(max-width: 400px){.woocommerce-filters-advanced{margin:12px 0}}.woocommerce-filters-advanced .woocommerce-filters-advanced__title-select{width:70px;display:inline-block;margin:0 8px}.woocommerce-filters-advanced__list{margin:0}.woocommerce-filters-advanced__list-item{padding:0 0 0 16px;margin:0;display:grid;grid-template-columns:1fr 40px;border-bottom:1px solid #ccc}.woocommerce-filters-advanced__list-item:hover{background-color:#e0e0e0}.woocommerce-filters-advanced__list-item .woocommerce-filters-advanced__line-item:nth-child(1){grid-column-start:1;grid-column-end:2;grid-row-start:1;grid-row-end:2}.woocommerce-filters-advanced__list-item .woocommerce-filters-advanced__line-item:nth-child(2){grid-column-start:2;grid-column-end:3;grid-row-start:1;grid-row-end:2}.woocommerce-filters-advanced__list-item fieldset{padding:8px 16px 8px 8px}.woocommerce-filters-advanced__list-item .woocommerce-filters-advanced__remove{width:40px;height:38px;align-self:center;color:#757575;padding:8px}@media(max-width: 400px){.woocommerce-filters-advanced__list-item .woocommerce-filters-advanced__remove{position:absolute;top:0;left:4px}}.woocommerce-filters-advanced__list-item .components-form-token-field{border-radius:4px}@media(max-width: 400px){.woocommerce-filters-advanced__list-item{display:block;position:relative;padding:8px 0 0 8px}}.woocommerce-filters-advanced__add-filter{margin:0;display:block}.woocommerce-filters-advanced__add-filter div div{display:inline-block}.woocommerce-filters-advanced__add-filter .components-popover:not(.is-mobile) .components-popover__content{min-width:180px}.woocommerce-filters-advanced__add-filter .components-popover__content>div{width:100%}.woocommerce-filters-advanced__fieldset{display:flex;align-items:center}.woocommerce-filters-advanced__fieldset>div{padding:0 4px}@media(max-width: 782px){.woocommerce-filters-advanced__fieldset>div{width:100%;padding:4px 0}}@media(max-width: 782px){.woocommerce-filters-advanced__fieldset{display:block}}.woocommerce-filters-advanced__fieldset.is-english{display:grid;grid-template-columns:120px 150px 1fr}.woocommerce-filters-advanced__fieldset.is-english .woocommerce-filters-advanced__fieldset-item:nth-child(1){grid-column-start:1;grid-column-end:2;grid-row-start:1;grid-row-end:2}.woocommerce-filters-advanced__fieldset.is-english .woocommerce-filters-advanced__fieldset-item:nth-child(2){grid-column-start:2;grid-column-end:3;grid-row-start:1;grid-row-end:2}.woocommerce-filters-advanced__fieldset.is-english .woocommerce-filters-advanced__fieldset-item:nth-child(3){grid-column-start:3;grid-column-end:4;grid-row-start:1;grid-row-end:2}.woocommerce-filters-advanced__fieldset.is-english .woocommerce-filters-advanced__fieldset-item:nth-child(1){display:flex;align-items:center}.woocommerce-filters-advanced__fieldset.is-english .woocommerce-filters-advanced__fieldset-item .components-base-control__field{margin-bottom:0}@media(max-width: 782px){.woocommerce-filters-advanced__fieldset.is-english{display:block}}.woocommerce-filters-advanced__rule{width:150px}.woocommerce-filters-advanced__input{width:100%}.woocommerce-filters-advanced__input.woocommerce-search.woocommerce-select-control .woocommerce-select-control__control{height:38px}.woocommerce-filters-advanced__add-filter-dropdown{display:inline-block}.woocommerce-filters-advanced__add-button{align-items:center;color:#757575;padding:8px}.woocommerce-filters-advanced__add-button svg{fill:currentColor;margin:0 0 0 6px}.woocommerce-filters-advanced__controls .components-button{margin-left:16px}.woocommerce-filters-advanced__add-dropdown{padding:0;margin:0;white-space:nowrap}.woocommerce-filters-advanced__add-dropdown li{margin:0}.woocommerce-filters-advanced__add-dropdown .components-button{width:100%;padding:8px}.woocommerce-filters-advanced__add-dropdown .components-button:hover{background-color:#e0e0e0}.woocommerce-filters-advanced__add-dropdown .components-button:not(:disabled):not([aria-disabled=true]):focus{background-color:#f0f0f0;box-shadow:none}.woocommerce-filters-advanced__input-range{align-items:center;display:grid;grid-template-columns:1fr}.woocommerce-filters-advanced__input-range.is-between{grid-template-columns:1fr 36px 1fr}.woocommerce-filters-advanced__input-range input{height:38px;margin:0}.woocommerce-filters-advanced__input-range .separator{text-align:center}.woocommerce-filters-advanced__attribute-fieldset{align-items:center;display:grid;grid-template-columns:1fr 20px 1fr}.woocommerce-filters-advanced__attribute-fieldset .woocommerce-filters-advanced__attribute-field-separator{padding:0 6px}.woocommerce-admin-page .woocommerce-filters-advanced__add-dropdown{text-wrap:nowrap}.woocommerce-filters-date__content.is-mobile .components-popover__header{border:none;height:0}.woocommerce-filters-date__content.is-mobile .components-popover__close{transform:translateY(22px)}.woocommerce-filters-date__content.is-mobile .components-tab-panel__tab-content{height:calc(100% - 46px);overflow:auto}.woocommerce-filters-date__content.components-dropdown__content .components-popover__content>div{padding:0}.woocommerce-filters-date__tabs{height:calc(100% - 42px);border-top:1px solid #ccc}.woocommerce-filters-date__tabs .components-tab-panel__tabs{display:flex;justify-content:space-between}.woocommerce-filters-date__tabs .components-tab-panel__tabs .components-button{display:block;text-align:center;width:50%}.woocommerce-filters-date__tabs .components-tab-panel__tab-content{display:flex;flex-direction:column;align-items:center}.woocommerce-filters-date__tabs:nth-child(1){grid-column-start:1;grid-column-end:2;grid-row-start:1;grid-row-end:2}.woocommerce-filters-date__tabs:nth-child(2){grid-column-start:2;grid-column-end:3;grid-row-start:1;grid-row-end:2}.woocommerce-filters-date__text{font-size:12px;font-size:0.75rem;font-weight:100;text-transform:uppercase;text-align:center;color:#757575;width:100%;margin:0;padding:1em;background-color:#fff}.woocommerce-filters-date__content-controls{display:flex;flex-direction:column;width:100%;align-items:center;padding-bottom:1em;background-color:#fff}.woocommerce-filters-date__content-controls.is-custom{border-top:1px solid #ccc}.woocommerce-filters-date__button-group{padding-top:1em;display:flex;justify-content:center;width:100%}.woocommerce-filters-date__button-group .woocommerce-filters-date__button{justify-content:center;width:40%;height:34px;margin:0 12px}.woocommerce-date-time-picker-control{display:block}.woocommerce-date-time-picker-control .components-input-control__suffix{margin-left:8px}.woocommerce-date-time-picker-control__popover .components-datetime__date{border-top:0}.woocommerce-filters-filter__content.is-mobile .components-popover__header-title{font-size:12px;font-size:0.75rem;font-weight:100;text-transform:uppercase;text-align:center;color:#757575}.woocommerce-filters-filter__content.is-mobile .woocommerce-filters-filter__content-list-item:last-child{border-bottom:1px solid #ccc}.woocommerce-filters-filter__content-list{margin:0;width:100%;min-width:100%}.woocommerce-filters-filter__content-list-item{border:1px solid rgba(0,0,0,0);border-bottom:1px solid #ccc;margin:0}.woocommerce-filters-filter__content-list-item:last-child{border-bottom:1px solid rgba(0,0,0,0)}.woocommerce-filters-filter__content-list-item.is-selected .woocommerce-filters-filter__button{background-color:#fff}.woocommerce-filters-filter__content-list-item.is-selected .woocommerce-filters-filter__button.components-button:not(:disabled):not([aria-disabled=true]):focus{background-color:#fff}.woocommerce-filters-filter__content-list-item.is-selected .woocommerce-filters-filter__button::before{content:"";width:8px;height:8px;background-color:#720eec;position:absolute;top:50%;right:1em;transform:translate(-50%, -50%)}.woocommerce-filters-filter__content-list-item .woocommerce-filters-filter__button{position:relative;align-items:center;display:flex;width:100%;padding:1em 3em 1em 1em;background-color:#f0f0f0;text-align:right}.woocommerce-filters-filter__content-list-item .woocommerce-filters-filter__button.components-button{color:#757575}.woocommerce-filters-filter__content-list-item .woocommerce-filters-filter__button:hover{background-color:#e0e0e0;color:#757575}.woocommerce-filters-filter__content-list-item .woocommerce-filters-filter__button.components-button:not(:disabled):not([aria-disabled=true]):focus{background-color:#f0f0f0}.woocommerce-filters-filter__content-list-item .woocommerce-filters-filter__button svg{position:absolute;right:1em}.woocommerce-filters .components-base-control__field{margin-bottom:0}@media(max-width: 400px){.woocommerce-filters{margin-right:-8px;margin-left:-8px}}.woocommerce-filters__basic-filters{display:flex;margin-bottom:24px}@media(max-width: 1280px){.woocommerce-filters__basic-filters{flex-direction:column}}@media(max-width: 782px){.woocommerce-filters__basic-filters{margin-bottom:16px}}.woocommerce-filters__advanced-filters .components-card__body{background-color:#f0f0f0}.woocommerce-filters__advanced-filters .components-card__footer .components-button{margin-left:16px}.woocommerce-filters-filter{width:25%;padding:0 12px;min-height:82px;display:flex;flex-direction:column;justify-content:flex-end}.woocommerce-filters-filter:first-child{padding-right:0}.woocommerce-filters-filter:last-child{padding-left:0}@media(max-width: 1440px){.woocommerce-filters-filter{width:33.3%}}@media(max-width: 1280px){.woocommerce-filters-filter{width:50%;padding:0;min-height:78px}}@media(max-width: 782px){.woocommerce-filters-filter{width:100%}}.woocommerce-filters-label{margin:7px 0;display:block}@media(max-width: 1280px){.woocommerce-filters-label{margin:5px 0}}.woocommerce-filters-date__content .components-popover__content,.woocommerce-filters-filter__content .components-popover__content{width:320px;border:1px solid #ccc;background-color:#fff;padding:0}.woocommerce-filters-date__content .woocommerce-calendar__input-error .components-popover__content,.woocommerce-filters-filter__content .woocommerce-calendar__input-error .components-popover__content{background-color:#757575}.woocommerce-filters-date__content.is-mobile .components-popover__content,.woocommerce-filters-filter__content.is-mobile .components-popover__content{width:100%;height:100%;border:none}.woocommerce-filters-filter__search .woocommerce-search__autocomplete-results{position:static}.woocommerce-filters-filter__search .woocommerce-search__inline-container{overflow:hidden}.woocommerce-filters-filter__search .woocommerce-search__inline-container:not(.is-active){border:none}.woocommerce-filters-advanced__list-item .components-base-control+.components-base-control{margin-bottom:0}.woocommerce-flag span{vertical-align:middle}.woocommerce-flag .woocommerce-flag__fallback{background:#f0f0f0;color:rgba(0,0,0,0);width:24px;height:18px;display:block;overflow:hidden}.woocommerce-form-section{display:grid;grid-template-columns:32% auto;gap:24px}.woocommerce-form-section__title{margin-bottom:12px;display:flex;align-items:center}.woocommerce-form-section__description>*:first-child{margin-top:0}.woocommerce-form-section__content .components-card{margin-bottom:16px}.woocommerce-form-section__content>*{width:100%}.woocommerce-image-upload .woocommerce-image-upload__image-preview{font-size:16px;margin-left:2em}.woocommerce-image-upload .woocommerce-image-upload__image-preview img{max-width:240px;height:auto}.woocommerce-image-upload .woocommerce-image-upload__add-image{margin:16px 0}.woocommerce-image-upload.has-image{display:flex;align-items:center}.woocommerce-image-gallery img{display:block}.woocommerce-image-gallery .woocommerce-sortable,.woocommerce-image-gallery__wrapper{display:grid;grid-template-columns:inherit;grid-gap:16px}.woocommerce-image-gallery .woocommerce-sortable__handle{display:block;margin:0}.woocommerce-image-gallery .woocommerce-sortable__item.is-dragging{position:absolute}.woocommerce-image-gallery .woocommerce-sortable__item.is-dragging-over-before:before{right:-9px}.woocommerce-image-gallery .woocommerce-sortable__item.is-dragging-over-after:after{left:-9px}.woocommerce-image-gallery__item{height:146px;width:146px;position:relative}.woocommerce-image-gallery__item.is-toolbar-visible img{border:2px solid #007cba}.woocommerce-image-gallery__item:not(.is-toolbar-visible) img:hover{border:1.5px solid #007cba}.woocommerce-image-gallery__item img{border:1px solid #e0e0e0;border-radius:3px;box-sizing:border-box;-o-object-fit:cover;object-fit:cover;width:100%;height:146px}.woocommerce-image-gallery__item .woocommerce-pill{background:var(--wp-admin-theme-color);border:0;color:#fff;padding-top:2px;padding-bottom:2px;position:absolute;top:10px;right:10px}.woocommerce-image-gallery__item .components-toolbar-group{flex-wrap:inherit}.woocommerce-image-gallery__item .components-toolbar-group svg{width:24px;margin-top:4px}.woocommerce-image-gallery__toolbar{width:-moz-max-content;width:max-content;position:absolute;top:-58px;right:50%;transform:translateX(50%);z-index:1000;background-color:#fff}.modal-open .woocommerce-image-gallery__toolbar-dropdown-popover{display:none}.woocommerce-list{margin:0;padding:0}a.woocommerce-list__item{color:inherit}.woocommerce-list__item{display:flex;align-items:center;margin-bottom:0;text-decoration:none;background-color:#fff}.woocommerce-list__item.has-gutters{padding:16px 24px}.woocommerce-list__item.has-action{cursor:pointer}.woocommerce-list__item:focus{box-shadow:inset 0 0 0 1px #3858e9,inset 0 0 0 2px #fff}.woocommerce-list__item:focus-visible{box-shadow:none}.woocommerce-list__item:not(.transitions-disabled).woocommerce-list__item-enter{opacity:0;max-height:0;transform:translateX(-50%)}.woocommerce-list__item:not(.transitions-disabled).woocommerce-list__item-enter-active{opacity:1;max-height:100vh;transform:translateX(0%);transition:opacity 500ms,transform 500ms,max-height 500ms}.woocommerce-list__item:not(.transitions-disabled).woocommerce-list__item-exit{opacity:1;max-height:100vh;transform:translateX(0%)}.woocommerce-list__item:not(.transitions-disabled).woocommerce-list__item-exit-active{opacity:0;max-height:0;transform:translateX(-50%);transition:opacity 500ms,transform 500ms,max-height 500ms}.woocommerce-list__item>.woocommerce-list__item-inner{text-decoration:none;width:100%;display:flex;align-items:center;padding:16px 24px}.woocommerce-list__item>.woocommerce-list__item-inner:focus{box-shadow:inset 0 0 0 1px #3858e9,inset 0 0 0 2px #fff}.woocommerce-list__item .woocommerce-list__item-title{color:#1d2327}.woocommerce-list__item .woocommerce-list__item-content{margin-top:4px;display:block;font-size:14px;line-height:20px;color:#50575d}.woocommerce-list__item .woocommerce-list__item-before{margin-left:20px;display:flex;align-items:center}.woocommerce-list__item .woocommerce-list__item-after{margin-right:16px;display:flex;align-items:center;margin-right:auto}.woocommerce-list__item:not(:first-child){border-top:1px solid #f0f0f0}.woocommerce-list__item:hover{background-color:#f0f0f0}.woocommerce-list__item:hover .woocommerce-list__item-title{color:var(--wp-admin-theme-color)}.woocommerce-list__item:hover .woocommerce-list__item-before>svg{fill:var(--wp-admin-theme-color)}.woocommerce-list__item .woocommerce-list__item-title,.woocommerce-list__item .woocommerce-list__item-title>div{color:var(--wp-admin-theme-color)}.woocommerce-list__item .woocommerce-list__item-before>svg{fill:var(--wp-admin-theme-color)}.woocommerce-list__item .woocommerce-list__item-after>svg{fill:#1e1e1e}.woocommerce-list__item.is-complete .woocommerce-task__icon{background-color:var(--wp-admin-theme-color)}.woocommerce-list__item.is-complete .woocommerce-list__item-title{color:#757575}.woocommerce-list__item.is-complete .woocommerce-list__item-content{display:none}.woocommerce-list__item-title{color:#2c3338}.woocommerce-list__item-content{color:#646970}.woocommerce-list-item{background:#fff;border:1px solid #ccc;margin:0;padding:16px;display:flex;align-items:center}.woocommerce-media-uploader{text-align:center}.woocommerce-media-uploader .woocommerce-media-uploader__label{font-weight:600;font-size:14px;line-height:20px;margin-bottom:24px;display:flex;flex-direction:column;align-items:center}.woocommerce-order-status{display:grid;grid-template-columns:min-content min-content;grid-gap:8px;align-items:center;white-space:nowrap}.woocommerce-order-status__indicator{min-width:16px;width:16px;height:16px;display:block;background:#ccc;border-radius:50%;border:3px solid #f0f0f0}.woocommerce-order-status__indicator.is-processing{background:#4ab866;border-color:#93d5a4}.woocommerce-order-status__indicator.is-on-hold{background:#ffb900;border-color:#ffd566}.woocommerce-pagination{display:flex;flex-direction:row;flex-wrap:nowrap;justify-content:center;align-items:center}@media(max-width: 782px){.woocommerce-pagination{flex-direction:column}}.woocommerce-pagination input{border-radius:4px}.woocommerce-pagination__page-arrows{display:flex;flex-direction:row;align-items:center;gap:8px}.woocommerce-pagination__page-arrows-buttons{display:inline-flex;align-items:baseline;border:1px solid #b5bfc9;border-radius:4px;background:#f0f2f4}.woocommerce-pagination__page-arrows-buttons .components-button{color:#24292d;height:30px;width:32px;justify-content:center}.woocommerce-pagination__page-arrows-buttons .components-button:not(:disabled):not([aria-disabled=true]):hover{color:#757575}.woocommerce-pagination__page-arrows-buttons button:first-child{border-top-left-radius:0;border-bottom-left-radius:0;border-left:2px solid #d3d9de}.woocommerce-pagination__page-arrows-buttons button:last-child{border-top-right-radius:0;border-bottom-right-radius:0}.woocommerce-pagination__page-arrows-buttons .woocommerce-pagination__link{padding:4px}.woocommerce-pagination__page-arrows-label{margin-top:8px;margin-left:8px}.woocommerce-pagination__page-picker{margin-right:16px}@media(max-width: 782px){.woocommerce-pagination__page-picker{margin-top:16px;margin-right:0}}.woocommerce-pagination__page-picker .woocommerce-pagination__page-picker-input{margin-right:8px;width:60px;height:34px;box-shadow:none}.woocommerce-pagination__per-page-picker{margin-right:16px}@media(max-width: 782px){.woocommerce-pagination__per-page-picker{margin-top:16px;margin-right:0}}.woocommerce-pagination__per-page-picker .components-base-control{margin-bottom:0}.woocommerce-pagination__per-page-picker .components-base-control .components-base-control__field{display:flex;flex-direction:row;align-items:baseline;margin-bottom:0}.woocommerce-pagination__per-page-picker .components-base-control .components-select-control__input{width:60px;height:34px;box-shadow:none}.woocommerce-pagination__per-page-picker .components-base-control .components-base-control__label{margin-left:8px}.woocommerce-pagination__per-page-picker .components-base-control label.components-input-control__label{font-size:13px;font-size:0.8125rem;line-height:18px;font-weight:400;text-transform:none}.woocommerce-pagination__page-picker-input.has-error,.woocommerce-pagination__page-picker-input.has-error:focus,.woocommerce-pagination__page-arrow-picker-input.has-error,.woocommerce-pagination__page-arrow-picker-input.has-error:focus{border-color:#d94f4f;box-shadow:0 0 2px #d94f4f}.woocommerce-pagination__page-arrow-picker-input::-webkit-outer-spin-button,.woocommerce-pagination__page-arrow-picker-input::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}.woocommerce-pagination__page-arrow-picker-input[type=number]{-moz-appearance:textfield}.woocommerce-pill{border:1px solid #757575;border-radius:28px;color:#757575;display:inline-block;padding:4px 8px}@media(max-width: 320px){.woocommerce-pill{font-size:11px}}.woocommerce-product-image{border-radius:2px}.woocommerce-rating{position:relative;vertical-align:middle;display:inline-block;overflow:hidden;white-space:nowrap}.woocommerce-rating .gridicon{fill:#e0e0e0}.woocommerce-rating .woocommerce-rating__star-outline{position:absolute;right:0;top:0;white-space:nowrap;overflow:hidden}.woocommerce-rating .woocommerce-rating__star-outline .gridicon{fill:#757575}.woocommerce-search.woocommerce-select-control{position:relative}.woocommerce-search.woocommerce-select-control .woocommerce-select-control__control-icon{position:absolute;top:50%;right:10px;transform:translateY(-50%);color:#ccc;font-size:20px}.woocommerce-search.woocommerce-select-control:not(.has-inline-tags) .woocommerce-tag{margin:8px 0 0 6px}.woocommerce-search.woocommerce-select-control .woocommerce-select-control__control{height:auto;border:1px solid #ccc;font-size:13px;width:100%;padding:3px 36px 3px 2px;border-radius:4px;border-color:#757575;box-shadow:0 1px 1px rgba(0,0,0,.03),0 1px 2px rgba(0,0,0,.02),0 3px 3px rgba(0,0,0,.02),0 4px 4px rgba(0,0,0,.01)}.woocommerce-search.woocommerce-select-control .woocommerce-select-control__control.is-active{border-color:var(--wp-admin-theme-color)}.woocommerce-search.woocommerce-select-control .components-base-control .woocommerce-select-control__control-input{margin:0;font-size:13px;min-height:auto}.woocommerce-search.woocommerce-select-control .components-base-control .woocommerce-select-control__control-input[type=number]::-webkit-outer-spin-button,.woocommerce-search.woocommerce-select-control .components-base-control .woocommerce-select-control__control-input[type=number]::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}.woocommerce-search.woocommerce-select-control .components-base-control .components-base-control__label{font-size:13px;color:#72777c;margin:0;width:calc(100% - 36px);top:50%;right:36px}.woocommerce-search.woocommerce-select-control .is-active.components-base-control .components-base-control__label,.woocommerce-search.woocommerce-select-control .with-value.components-base-control .components-base-control__label,.woocommerce-search.woocommerce-select-control.has-inline-tags .has-tags.components-base-control .components-base-control__label{display:none}.woocommerce-search.woocommerce-select-control .components-base-control .woocommerce-select-control__tags{margin:0}.woocommerce-search.woocommerce-select-control .components-base-control .woocommerce-tag{max-height:24px}.woocommerce-search.woocommerce-select-control .woocommerce-select-control__listbox{border:1px solid #ccc;top:38px}.woocommerce-search.woocommerce-select-control.is-static-results .woocommerce-select-control__listbox{position:static}.woocommerce-search.woocommerce-select-control .woocommerce-select-control__option{margin-bottom:0;display:flex;flex-direction:row;flex-grow:1;flex-shrink:0;align-items:center;padding:12px;color:#720eec;text-align:right;background:#f0f0f0;border-bottom:1px solid #f0f0f0;font-size:13px;min-height:43px;height:auto}.woocommerce-search.woocommerce-select-control .woocommerce-select-control__option:last-of-type{border-bottom:none}.woocommerce-search.woocommerce-select-control .woocommerce-select-control__option:hover{box-shadow:none;color:#720eec;background:#e0e0e0}.woocommerce-search.woocommerce-select-control .woocommerce-select-control__option.is-selected,.woocommerce-search.woocommerce-select-control .woocommerce-select-control__option:focus,.woocommerce-search.woocommerce-select-control .woocommerce-select-control__option:active{color:#720eec;background:#fff;box-shadow:inset 0 0 0 1px #e0e0e0,inset 0 0 0 2px #24292d}.woocommerce-search.woocommerce-select-control .woocommerce-select-control__option .woocommerce-search__result-thumbnail{margin-left:12px}.woocommerce-search__result-name{text-decoration:underline}.woocommerce-search-list{width:100%;padding:0 0 16px;text-align:right}.woocommerce-search-list__selected{margin:16px 0;padding:16px 0 0;min-height:76px;border-top:1px solid #f0f0f0}.woocommerce-search-list__selected .woocommerce-search-list__selected-header{margin-bottom:8px}.woocommerce-search-list__selected .woocommerce-search-list__selected-header button{margin-right:12px}.woocommerce-search-list__selected .woocommerce-tag__text{max-width:13em}.woocommerce-search-list__selected ul{list-style:none}.woocommerce-search-list__selected ul li{float:right}.woocommerce-search-list__search{margin:16px 0;padding:16px 0 0;border-top:1px solid #f0f0f0}.woocommerce-search-list__search .components-base-control__field{margin-bottom:16px}.woocommerce-search-list__list{border:1px solid #e0e0e0;padding:0;max-height:17em;overflow-x:hidden;overflow-y:auto}.woocommerce-search-list__list li{margin-bottom:0}.woocommerce-search-list__list.is-loading{padding:12px 0;text-align:center;border:none}.woocommerce-search-list__list.is-not-found{padding:12px 0;text-align:center;border:none}.woocommerce-search-list__list.is-not-found .woocommerce-search-list__not-found-icon,.woocommerce-search-list__list.is-not-found .woocommerce-search-list__not-found-text{display:inline-block}.woocommerce-search-list__list.is-not-found .woocommerce-search-list__not-found-icon{margin-left:16px}.woocommerce-search-list__list.is-not-found .woocommerce-search-list__not-found-icon .gridicon{vertical-align:top;margin-top:-1px}.woocommerce-search-list__list .components-spinner{float:none;margin:0 auto}.woocommerce-search-list__list .components-menu-group__label{clip:rect(1px, 1px, 1px, 1px);clip-path:inset(50%);height:1px;width:1px;margin:-1px;overflow:hidden;overflow-wrap:normal !important;word-wrap:normal !important}.woocommerce-search-list__list>[role=menu]{border:1px solid #f0f0f0;border-bottom:none}.woocommerce-search-list__list .woocommerce-search-list__item{display:flex;align-items:center;margin-bottom:0;padding:12px 16px;background:#fff;border-bottom:1px solid #f0f0f0;color:#757575}.woocommerce-search-list__list .woocommerce-search-list__item:hover,.woocommerce-search-list__list .woocommerce-search-list__item:active,.woocommerce-search-list__list .woocommerce-search-list__item:focus{background:#f0f0f0}.woocommerce-search-list__list .woocommerce-search-list__item:active,.woocommerce-search-list__list .woocommerce-search-list__item:focus{box-shadow:none}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-input{margin:0 0 0 8px}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-label{display:flex;flex:1}.woocommerce-search-list__list .woocommerce-search-list__item.depth-0+.depth-1{margin-top:-1px}.woocommerce-search-list__list .woocommerce-search-list__item:not(.depth-0){border-bottom:0 !important}.woocommerce-search-list__list .woocommerce-search-list__item:not(.depth-0)+.depth-0{border-top:1px solid #f0f0f0}.woocommerce-search-list__list .woocommerce-search-list__item[class*=depth-] .woocommerce-search-list__item-label::before{margin-left:4px;content:"— — — — — "}.woocommerce-search-list__list .woocommerce-search-list__item.depth-0 .woocommerce-search-list__item-label::before{margin-left:0;content:""}.woocommerce-search-list__list .woocommerce-search-list__item.depth-1 .woocommerce-search-list__item-label::before{content:"— "}.woocommerce-search-list__list .woocommerce-search-list__item.depth-2 .woocommerce-search-list__item-label::before{content:"— — "}.woocommerce-search-list__list .woocommerce-search-list__item.depth-3 .woocommerce-search-list__item-label::before{content:"— — — "}.woocommerce-search-list__list .woocommerce-search-list__item.depth-4 .woocommerce-search-list__item-label::before{content:"— — — — "}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-name{display:inline-block}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-prefix{display:none;color:#757575}.woocommerce-search-list__list .woocommerce-search-list__item.is-searching .woocommerce-search-list__item-label,.woocommerce-search-list__list .woocommerce-search-list__item.is-skip-level .woocommerce-search-list__item-label{display:inline-block}.woocommerce-search-list__list .woocommerce-search-list__item.is-searching .woocommerce-search-list__item-prefix,.woocommerce-search-list__list .woocommerce-search-list__item.is-skip-level .woocommerce-search-list__item-prefix{display:inline}.woocommerce-search-list__list .woocommerce-search-list__item.is-searching .woocommerce-search-list__item-prefix::after,.woocommerce-search-list__list .woocommerce-search-list__item.is-skip-level .woocommerce-search-list__item-prefix::after{margin-left:4px;content:" ›"}.woocommerce-search-list__list .woocommerce-search-list__item.is-searching .woocommerce-search-list__item-name{color:#1e1e1e}.woocommerce-search-list__list .woocommerce-search-list__item.has-count>.components-menu-item__item{width:100%}.woocommerce-search-list__list .woocommerce-search-list__item .woocommerce-search-list__item-count{flex:0 1 auto;padding:2px 8px;border:1px solid #f0f0f0;border-radius:12px;font-size:.8em;line-height:1.4;color:#757575;background:#fff;white-space:nowrap}.woocommerce-search-list__list li:last-child .woocommerce-search-list__item{border-bottom:none}.woocommerce-search-list.is-compact .woocommerce-search-list__selected{margin:0 0 16px;padding:0;border-top:none;min-height:54px}.woocommerce-search-list.is-compact .woocommerce-search-list__search{margin:0 0 16px;padding:0;border-top:none}.woocommerce-section-header{padding:13px;border-bottom:none;display:flex;justify-content:space-between}@media(max-width: 782px){.woocommerce-section-header{margin-right:-16px;margin-left:-16px;margin-bottom:12px;border-right:none;border-left:none;width:auto}}.woocommerce-section-header hr{align-self:center;flex-grow:1;height:1px;margin:0 10px}@media(max-width: 782px){.woocommerce-section-header.has-interval-select{position:relative;padding-bottom:30px}.woocommerce-section-header.has-interval-select .woocommerce-chart__interval-select{position:absolute;right:0;bottom:0;padding-right:6px}}.woocommerce-section-header__actions,.woocommerce-section-header__menu{text-align:left}.woocommerce-section-header__actions{display:flex;flex-grow:1;justify-content:flex-end}.woocommerce-section-header__actions .components-base-control .components-base-control__field select{background:rgba(0,0,0,0)}.woocommerce-ellipsis-menu__toggle{padding:0}.woocommerce-section-header__menu{display:flex;flex-direction:column;justify-content:center}.woocommerce-section-header__title{margin:0 0 0 16px;padding:3px 0;font-size:20px;font-size:1.25rem;line-height:2.2;font-weight:400}.woocommerce-segmented-selection{width:100%;color:#757575}.woocommerce-segmented-selection__container{width:100%;grid-template-columns:1fr 1fr;display:grid;border-top:1px solid #ccc;border-bottom:1px solid #ccc;background-color:#ccc}.woocommerce-segmented-selection__item:nth-child(2n){border-right:1px solid #ccc;border-top:1px solid #ccc}.woocommerce-segmented-selection__item:nth-child(2n+1){border-top:1px solid #ccc}.woocommerce-segmented-selection__item:nth-child(-n+2){border-top:0}.woocommerce-segmented-selection__label{background-color:#f0f0f0;padding:12px 36px 12px 12px;position:relative;display:block;height:100%}.woocommerce-segmented-selection__label:active{background-color:#e0e0e0}.woocommerce-segmented-selection__label:hover{background-color:#e0e0e0}.woocommerce-segmented-selection__input{opacity:0;position:absolute;right:-9999px}.woocommerce-segmented-selection__input:active+label .woocommerce-segmented-selection__label{background-color:#e0e0e0}.woocommerce-segmented-selection__input:checked+label .woocommerce-segmented-selection__label{background-color:#fff;font-weight:600}.woocommerce-segmented-selection__input:checked+label .woocommerce-segmented-selection__label::before{content:"";width:8px;height:8px;background-color:var(--wp-admin-theme-color);position:absolute;top:50%;transform:translate(20px, -50%)}.woocommerce-segmented-selection__input:focus+label .woocommerce-segmented-selection__label{box-shadow:inset 0 0 0 1px #24292d}.woocommerce-select-control{position:relative}.woocommerce-select-control .components-base-control{height:56px;display:flex;box-sizing:border-box;align-items:center;border:1px solid #a7aaad;border-radius:3px;background:#fff;padding:12px;position:relative}.woocommerce-select-control .components-base-control .woocommerce-select-control__tags{margin:12px 0 0 4px}.woocommerce-select-control .components-base-control .woocommerce-tag{max-height:20px}.woocommerce-select-control .components-base-control .components-base-control__field{display:flex;align-items:center;flex:1;margin-bottom:0;max-width:100%}.woocommerce-select-control .components-base-control .components-base-control__label{position:absolute;top:50%;transform:translateY(-50%);color:#646970;font-size:16px;line-height:1.5em}.woocommerce-select-control .components-base-control .woocommerce-select-control__control-input{font-size:16px;border:0;box-shadow:none;color:#2c3338;margin:12px 0 0 0;padding-right:0;padding-left:0;width:100%;line-height:24px;text-align:right;letter-spacing:inherit;background:rgba(0,0,0,0)}.woocommerce-select-control .components-base-control .woocommerce-select-control__control-input::-webkit-search-cancel-button{display:none}.woocommerce-select-control .components-base-control .woocommerce-select-control__control-input:focus{outline:none}.woocommerce-select-control .components-base-control i{color:#636d75;margin-left:12px;width:24px}.woocommerce-select-control .components-base-control.is-active{box-shadow:0 0 0 1px #3858e9;border-color:#3858e9}.woocommerce-select-control .components-base-control.with-value .components-base-control__label,.woocommerce-select-control .components-base-control.has-tags .components-base-control__label{font-size:12px;margin-top:-12px}.woocommerce-select-control .components-base-control.is-disabled{opacity:.5}.woocommerce-select-control .components-base-control.is-disabled .components-base-control__label{cursor:default}.woocommerce-select-control .woocommerce-select-control__autofill-input{position:absolute;z-index:-1}.woocommerce-select-control .woocommerce-select-control__tags{position:relative;margin:12px 0 0 0}.woocommerce-select-control .woocommerce-select-control__tags.has-clear{padding-left:24px}.woocommerce-select-control .woocommerce-tag{max-height:24px}.woocommerce-select-control .woocommerce-select-control__clear{position:absolute;left:10px;top:calc(50% - 10px)}.woocommerce-select-control .woocommerce-select-control__clear>.clear-icon{color:#c9c9c9}.woocommerce-select-control .woocommerce-select-control__listbox{background:#fff;display:flex;flex-direction:column;align-items:stretch;box-shadow:0 3px 5px rgba(0,0,0,.2),0 1px 18px rgba(0,0,0,.12),0 6px 10px rgba(0,0,0,.14);border-radius:3px;position:absolute;right:0;left:0;top:57px;z-index:10;overflow-y:auto;max-height:362px}.woocommerce-select-control .woocommerce-select-control__listbox.is-static{position:static}.woocommerce-select-control .woocommerce-select-control__listbox.is-virtual{overflow:hidden}.woocommerce-select-control .woocommerce-select-control__option{padding:16px;min-height:56px;font-size:16px;text-align:right}.woocommerce-select-control .woocommerce-select-control__option.is-selected,.woocommerce-select-control .woocommerce-select-control__option:hover{background:#f6f7f7}.woocommerce-select-control.is-searchable .components-base-control__label{right:48px}.woocommerce-select-control.is-searchable .components-base-control.is-active .components-base-control__label{font-size:12px;margin-top:-12px}.woocommerce-select-control.is-searchable .woocommerce-select-control__control-input{padding-right:12px}.woocommerce-sortable li{list-style:none}.woocommerce-sortable__item{margin:0;position:relative}.woocommerce-sortable__item.is-dragging{opacity:0;height:0;width:0}.woocommerce-sortable__item:before,.woocommerce-sortable__item:after{content:"";display:none;height:3px;width:100%;background:var(--wp-admin-theme-color);border-radius:24px;position:absolute;top:-1.5px}.woocommerce-sortable__item:after{top:auto;bottom:-1.5px}.is-horizontal .woocommerce-sortable__item:before,.is-horizontal .woocommerce-sortable__item:after{height:100%;width:3px}.is-horizontal .woocommerce-sortable__item:before{top:0;right:-1.5px}.is-horizontal .woocommerce-sortable__item:after{top:0;bottom:auto;left:-1.5px}.woocommerce-sortable__item.is-dragging-over-before:before{display:block}.woocommerce-sortable__item.is-dragging-over-after.is-last-droppable:after{display:block}.woocommerce-sortable__handle{cursor:grab;margin-left:16px;display:inline-flex}.woocommerce-stepper .woocommerce-stepper__steps{display:flex;justify-content:space-around;margin-bottom:24px}.woocommerce-stepper .woocommerce-stepper__step{padding:8px;font-weight:400;position:relative}.woocommerce-stepper .woocommerce-stepper__step .woocommerce-stepper__step-label-wrapper{display:flex;text-align:right;border:0;background-color:rgba(0,0,0,0);padding:0}.woocommerce-stepper .woocommerce-stepper__step .woocommerce-stepper__step-label-wrapper:focus{outline:none;box-shadow:none}.woocommerce-stepper .woocommerce-stepper__step button.woocommerce-stepper__step-label-wrapper{cursor:pointer}.woocommerce-stepper .woocommerce-stepper__step .woocommerce-stepper__step-text{width:100%}.woocommerce-stepper .woocommerce-stepper__step .woocommerce-stepper__step-label{color:#1e1e1e;line-height:24px;font-size:16px}.woocommerce-stepper .woocommerce-stepper__step .woocommerce-stepper__step-description{display:none;font-size:14px;color:#757575;font-weight:400;margin-top:2px}.woocommerce-stepper .woocommerce-stepper__step .woocommerce-stepper__step-icon svg{display:none}.woocommerce-stepper .woocommerce-stepper__step .woocommerce-spinner{display:block;margin-left:12px;max-height:24px;min-width:24px;width:24px;border-radius:50%;background:var(--wp-admin-theme-color)}.woocommerce-stepper .woocommerce-stepper__step .woocommerce-spinner__circle{stroke:#fff}.woocommerce-stepper .woocommerce-stepper__step.is-active .woocommerce-stepper__step-icon,.woocommerce-stepper .woocommerce-stepper__step.is-complete .woocommerce-stepper__step-icon{background:var(--wp-admin-theme-color);color:#fff}.woocommerce-stepper .woocommerce-stepper__step.is-active .woocommerce-stepper__step-label,.woocommerce-stepper .woocommerce-stepper__step.is-complete .woocommerce-stepper__step-label{color:#1e1e1e}.woocommerce-stepper .woocommerce-stepper__step.is-active .woocommerce-stepper__step-icon{font-weight:600}.woocommerce-stepper .woocommerce-stepper__step.is-active .woocommerce-stepper__step-label{font-weight:600;margin:0}.woocommerce-stepper .woocommerce-stepper__step.is-complete .woocommerce-stepper__step-number{display:none}.woocommerce-stepper .woocommerce-stepper__step.is-complete svg{display:inline}.woocommerce-stepper .woocommerce-stepper__step-icon{font-size:16px;display:inline-flex;align-items:center;justify-content:center;width:24px;height:24px;min-width:24px;margin-left:12px;background:#f0f0f0;color:#757575;border-radius:50%}.woocommerce-stepper .woocommerce-stepper__step-divider{align-self:flex-start;flex-grow:1;border-bottom:1px solid #f0f0f0;margin-top:20px}.woocommerce-stepper .woocommerce-stepper__step-divider:last-child{display:none}@media(max-width: 782px){.woocommerce-stepper .woocommerce-stepper__step-label{display:none;padding-top:24px}.woocommerce-stepper .woocommerce-stepper__step-icon{margin-left:0}}.woocommerce-stepper.is-vertical .woocommerce-stepper__steps{align-items:initial;flex-direction:column;margin-bottom:0}.woocommerce-stepper.is-vertical .woocommerce-stepper__step{padding-bottom:36px}.woocommerce-stepper.is-vertical .woocommerce-stepper__step::after{content:"";position:absolute;right:20px;top:40px;height:calc(100% - 24px - 16px);border-right:1px solid #f0f0f0}.woocommerce-stepper.is-vertical .woocommerce-stepper__step:last-child{padding-bottom:8px}.woocommerce-stepper.is-vertical .woocommerce-stepper__step:last-child::after{display:none}.woocommerce-stepper.is-vertical .woocommerce-stepper__step-label{display:initial}.woocommerce-stepper.is-vertical .woocommerce-stepper__step-icon{margin-left:12px}.woocommerce-stepper.is-vertical .woocommerce-stepper__step-description{display:block}.woocommerce-stepper.is-vertical .woocommerce-stepper_content{margin-top:16px;margin-right:36px}@keyframes rotate{0%{transform:rotate(0deg)}100%{transform:rotate(-270deg)}}@keyframes growAndShrink{0%,100%{stroke-dashoffset:200}50%{stroke-dashoffset:50;transform:rotate(-135deg)}100%{transform:rotate(-450deg)}}.woocommerce-spinner{animation:rotate 2s linear infinite;width:40px;min-width:40px;height:40px;max-height:40px}.woocommerce-spinner__circle{stroke-dasharray:200;stroke-dashoffset:0;transform-origin:center;animation:growAndShrink 2s ease-in-out infinite;stroke:#1d2327}.woocommerce-summary{margin:16px 0;display:grid;border-width:1px 1px 0 0;border-style:solid;border-color:#e0e0e0;background-color:#f0f0f0;box-shadow:inset 1px -1px 0 #e0e0e0;width:100%}@media(max-width: 782px){.woocommerce-summary{border-width:0}.woocommerce-summary.is-placeholder{border-top:0}.woocommerce-summary .woocommerce-summary__item-container.is-placeholder{border-top:1px solid #e0e0e0}}.woocommerce-summary .components-popover:not(.components-tooltip){position:static !important;top:auto !important;right:auto !important;left:auto !important;bottom:auto !important;margin-top:0 !important;margin-right:0}.woocommerce-summary .components-popover:not(.components-tooltip) .components-popover__header{display:none}.woocommerce-summary .components-popover:not(.components-tooltip) .components-popover__content{position:static;right:auto;left:auto;margin:0;width:100%;max-width:100% !important;max-height:100% !important;box-shadow:none;border:none;transform:none}.woocommerce-summary .components-popover:not(.components-tooltip) .components-popover__content .woocommerce-summary__item.is-selected{display:none}.components-popover__content .woocommerce-summary{max-height:100%;margin-top:0;margin-bottom:0;overflow-y:auto;border:none}.woocommerce-summary .woocommerce-summary__item-value,.woocommerce-summary .woocommerce-summary__item-delta{flex:1 0 auto}.woocommerce-summary .woocommerce-summary__item-delta{flex:0 1 auto;display:flex}.woocommerce-summary,.woocommerce-summary.has-one-item,.woocommerce-summary.has-1-items{grid-template-columns:1fr}.woocommerce-summary.has-2-items{grid-template-columns:repeat(2, 1fr)}.woocommerce-summary.has-2-items .woocommerce-summary__item-container:nth-of-type(2n) .woocommerce-summary__item{border-left-color:#e0e0e0}.woocommerce-summary.has-2-items .woocommerce-summary__item-container:nth-of-type(2n
+ 1):nth-last-of-type(-n + 2) .woocommerce-summary__item,.woocommerce-summary.has-2-items .woocommerce-summary__item-container:nth-of-type(2n
+ 1):nth-last-of-type(-n + 2)~.woocommerce-summary__item-container .woocommerce-summary__item{border-bottom-color:#e0e0e0}.woocommerce-summary.has-3-items{grid-template-columns:repeat(3, 1fr)}.woocommerce-summary.has-3-items .woocommerce-summary__item-container:nth-of-type(3n) .woocommerce-summary__item{border-left-color:#e0e0e0}.woocommerce-summary.has-3-items .woocommerce-summary__item-container:nth-of-type(3n
+ 1):nth-last-of-type(-n + 3) .woocommerce-summary__item,.woocommerce-summary.has-3-items .woocommerce-summary__item-container:nth-of-type(3n
+ 1):nth-last-of-type(-n + 3)~.woocommerce-summary__item-container .woocommerce-summary__item{border-bottom-color:#e0e0e0}.woocommerce-summary.has-4-items,.woocommerce-summary.has-7-items,.woocommerce-summary.has-8-items{grid-template-columns:repeat(4, 1fr)}.woocommerce-summary.has-4-items .woocommerce-summary__item-container:nth-of-type(4n) .woocommerce-summary__item,.woocommerce-summary.has-7-items .woocommerce-summary__item-container:nth-of-type(4n) .woocommerce-summary__item,.woocommerce-summary.has-8-items .woocommerce-summary__item-container:nth-of-type(4n) .woocommerce-summary__item{border-left-color:#e0e0e0}.woocommerce-summary.has-4-items .woocommerce-summary__item-container:nth-of-type(4n
+ 1):nth-last-of-type(-n + 4) .woocommerce-summary__item,.woocommerce-summary.has-4-items .woocommerce-summary__item-container:nth-of-type(4n
+ 1):nth-last-of-type(-n + 4)~.woocommerce-summary__item-container .woocommerce-summary__item,.woocommerce-summary.has-7-items .woocommerce-summary__item-container:nth-of-type(4n
+ 1):nth-last-of-type(-n + 4) .woocommerce-summary__item,.woocommerce-summary.has-7-items .woocommerce-summary__item-container:nth-of-type(4n
+ 1):nth-last-of-type(-n + 4)~.woocommerce-summary__item-container .woocommerce-summary__item,.woocommerce-summary.has-8-items .woocommerce-summary__item-container:nth-of-type(4n
+ 1):nth-last-of-type(-n + 4) .woocommerce-summary__item,.woocommerce-summary.has-8-items .woocommerce-summary__item-container:nth-of-type(4n
+ 1):nth-last-of-type(-n + 4)~.woocommerce-summary__item-container .woocommerce-summary__item{border-bottom-color:#e0e0e0}.woocommerce-summary.has-5-items{grid-template-columns:repeat(5, 1fr)}.woocommerce-summary.has-5-items .woocommerce-summary__item-container:nth-of-type(5n) .woocommerce-summary__item{border-left-color:#e0e0e0}.woocommerce-summary.has-5-items .woocommerce-summary__item-container:nth-of-type(5n
+ 1):nth-last-of-type(-n + 5) .woocommerce-summary__item,.woocommerce-summary.has-5-items .woocommerce-summary__item-container:nth-of-type(5n
+ 1):nth-last-of-type(-n + 5)~.woocommerce-summary__item-container .woocommerce-summary__item{border-bottom-color:#e0e0e0}.woocommerce-summary.has-5-items .woocommerce-summary__item-value .woocommerce-summary__item-prev-label,.woocommerce-summary.has-5-items.is-placeholder .woocommerce-summary__item-prev-label{margin-left:calc(100% - 80px)}@media(min-width: 1441px){.woocommerce-summary.has-6-items{grid-template-columns:repeat(6, 1fr)}.woocommerce-summary.has-6-items .woocommerce-summary__item-container:nth-of-type(6n) .woocommerce-summary__item{border-left-color:#e0e0e0}.woocommerce-summary.has-6-items .woocommerce-summary__item-container:nth-of-type(6n
+ 1):nth-last-of-type(-n + 6) .woocommerce-summary__item,.woocommerce-summary.has-6-items .woocommerce-summary__item-container:nth-of-type(6n
+ 1):nth-last-of-type(-n + 6)~.woocommerce-summary__item-container .woocommerce-summary__item{border-bottom-color:#e0e0e0}.woocommerce-summary.has-6-items .woocommerce-summary__item-value .woocommerce-summary__item-prev-label,.woocommerce-summary.has-6-items.is-placeholder .woocommerce-summary__item-prev-label{margin-left:calc(100% - 80px)}.woocommerce-summary.has-9-items,.woocommerce-summary.has-10-items{grid-template-columns:repeat(5, 1fr)}.woocommerce-summary.has-9-items .woocommerce-summary__item-container:nth-of-type(5n) .woocommerce-summary__item,.woocommerce-summary.has-10-items .woocommerce-summary__item-container:nth-of-type(5n) .woocommerce-summary__item{border-left-color:#e0e0e0}.woocommerce-summary.has-9-items .woocommerce-summary__item-container:nth-of-type(5n
+ 1):nth-last-of-type(-n + 5) .woocommerce-summary__item,.woocommerce-summary.has-9-items .woocommerce-summary__item-container:nth-of-type(5n
+ 1):nth-last-of-type(-n + 5)~.woocommerce-summary__item-container .woocommerce-summary__item,.woocommerce-summary.has-10-items .woocommerce-summary__item-container:nth-of-type(5n
+ 1):nth-last-of-type(-n + 5) .woocommerce-summary__item,.woocommerce-summary.has-10-items .woocommerce-summary__item-container:nth-of-type(5n
+ 1):nth-last-of-type(-n + 5)~.woocommerce-summary__item-container .woocommerce-summary__item{border-bottom-color:#e0e0e0}.woocommerce-summary.has-9-items .woocommerce-summary__item-value .woocommerce-summary__item-prev-label,.woocommerce-summary.has-9-items.is-placeholder .woocommerce-summary__item-prev-label,.woocommerce-summary.has-10-items .woocommerce-summary__item-value .woocommerce-summary__item-prev-label,.woocommerce-summary.has-10-items.is-placeholder .woocommerce-summary__item-prev-label{margin-left:calc(100% - 80px)}}@media(max-width: 1440px){.woocommerce-summary.has-4-items .woocommerce-summary__item-value .woocommerce-summary__item-prev-label,.woocommerce-summary.has-4-items.is-placeholder .woocommerce-summary__item-prev-label,.woocommerce-summary.has-7-items .woocommerce-summary__item-value .woocommerce-summary__item-prev-label,.woocommerce-summary.has-7-items.is-placeholder .woocommerce-summary__item-prev-label,.woocommerce-summary.has-8-items .woocommerce-summary__item-value .woocommerce-summary__item-prev-label,.woocommerce-summary.has-8-items.is-placeholder .woocommerce-summary__item-prev-label{margin-left:calc(100% - 80px)}.woocommerce-summary.has-6-items,.woocommerce-summary.has-9-items{grid-template-columns:repeat(3, 1fr)}.woocommerce-summary.has-6-items .woocommerce-summary__item-container:nth-of-type(3n) .woocommerce-summary__item,.woocommerce-summary.has-9-items .woocommerce-summary__item-container:nth-of-type(3n) .woocommerce-summary__item{border-left-color:#e0e0e0}.woocommerce-summary.has-6-items .woocommerce-summary__item-container:nth-of-type(3n
+ 1):nth-last-of-type(-n + 3) .woocommerce-summary__item,.woocommerce-summary.has-6-items .woocommerce-summary__item-container:nth-of-type(3n
+ 1):nth-last-of-type(-n + 3)~.woocommerce-summary__item-container .woocommerce-summary__item,.woocommerce-summary.has-9-items .woocommerce-summary__item-container:nth-of-type(3n
+ 1):nth-last-of-type(-n + 3) .woocommerce-summary__item,.woocommerce-summary.has-9-items .woocommerce-summary__item-container:nth-of-type(3n
+ 1):nth-last-of-type(-n + 3)~.woocommerce-summary__item-container .woocommerce-summary__item{border-bottom-color:#e0e0e0}.woocommerce-summary.has-10-items{grid-template-columns:repeat(4, 1fr)}.woocommerce-summary.has-10-items .woocommerce-summary__item-container:nth-of-type(4n) .woocommerce-summary__item{border-left-color:#e0e0e0}.woocommerce-summary.has-10-items .woocommerce-summary__item-container:nth-of-type(4n
+ 1):nth-last-of-type(-n + 4) .woocommerce-summary__item,.woocommerce-summary.has-10-items .woocommerce-summary__item-container:nth-of-type(4n
+ 1):nth-last-of-type(-n + 4)~.woocommerce-summary__item-container .woocommerce-summary__item{border-bottom-color:#e0e0e0}.woocommerce-summary.has-10-items .woocommerce-summary__item-value .woocommerce-summary__item-prev-label,.woocommerce-summary.has-10-items.is-placeholder .woocommerce-summary__item-prev-label{margin-left:calc(100% - 80px)}.woocommerce-summary.has-9-items .woocommerce-summary__item-container:nth-of-type(5n) .woocommerce-summary__item,.woocommerce-summary.has-10-items .woocommerce-summary__item-container:nth-of-type(5n) .woocommerce-summary__item{border-left-color:#e0e0e0}}@media(max-width: 960px){.woocommerce-summary .woocommerce-summary__item{border-left-color:#e0e0e0}}@media(max-width: 782px){.woocommerce-summary .woocommerce-summary__item-container{margin-right:-16px;margin-left:-16px;width:auto}.woocommerce-summary .woocommerce-summary__item-container .woocommerce-summary__item{border-left:none}.woocommerce-summary .components-popover.components-popover{margin-right:-16px;margin-left:-16px}.woocommerce-summary .components-popover.components-popover .woocommerce-summary__item-container{margin-right:0;margin-left:0}}.woocommerce-summary__item-container{margin-bottom:0}.woocommerce-summary__item-container:last-of-type .woocommerce-summary__item{border-bottom-color:#e0e0e0 !important}.woocommerce-summary__item-container.is-dropdown-button{padding:0;list-style:none;border-left:1px solid #e0e0e0}.woocommerce-summary__item-container.is-dropdown-button .components-button{border-bottom:1px solid #e0e0e0;text-align:right;display:block}@media(max-width: 782px){.woocommerce-summary__item-container.is-dropdown-button{border-left:none}}.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item{height:117px}.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item-label{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);display:inline-block;height:20px;margin-top:2.2px;max-width:110px;width:70%}.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item-label::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item-label{animation:none}}.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item-data{justify-content:space-between}.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item-value{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);display:inline-block;height:28px;width:60px;max-width:60px}.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item-value::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item-value{animation:none}}.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item-delta{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);width:60px;border-radius:2px}.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item-delta::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-summary__item-container.is-placeholder .woocommerce-summary__item-delta{animation:none}}.woocommerce-summary__item{display:flex;flex-direction:column;height:100%;padding:24px;background-color:#f8f9fa;border-bottom:1px solid #e0e0e0;border-left:1px solid #e0e0e0;line-height:1.4em;text-decoration:none;color:#1e1e1e}.woocommerce-summary__item.components-button{height:auto;padding:16px;align-items:normal}.woocommerce-summary__item:hover{background-color:#f0f0f0;color:var(--wp-admin-theme-color)}.woocommerce-summary__item:hover .woocommerce-summary__item-label{color:var(--wp-admin-theme-color)}.woocommerce-summary__item:active{background-color:#f0f0f0}.woocommerce-summary__item:focus{box-shadow:inset 1px 1px 0 #757575,inset -1px -1px 0 #757575 !important}.woocommerce-summary__item.is-selected:focus{box-shadow:inset 1px -1px 0 #757575,inset -1px 0 0 #757575,inset 0 4px 0 var(--wp-admin-theme-color) !important}.is-dropdown-button .woocommerce-summary__item{position:relative;width:100%;padding-left:56px}@media(max-width: 782px){.is-dropdown-button .woocommerce-summary__item{border-left:none}}.woocommerce-summary__item .woocommerce-summary__item-data{display:flex;justify-content:space-between}.woocommerce-summary__item .woocommerce-summary__item-label{display:flex;margin-bottom:16px;color:#757575}.woocommerce-summary__item .woocommerce-summary__info-tooltip{color:#949494;line-height:1em;margin-right:4px}.woocommerce-summary__item .woocommerce-summary__info-tooltip svg{fill:currentColor}.woocommerce-summary__item .woocommerce-summary__item-value{margin-bottom:4px;font-weight:500;color:#1e1e1e}.woocommerce-summary__item .woocommerce-summary__item-delta{padding:5px;border-radius:3px;height:-moz-min-content;height:min-content;background-color:#f0f0f0;color:#1e1e1e}.woocommerce-summary__item.is-selected{background:#fff;box-shadow:inset 0 4px 0 var(--wp-admin-theme-color)}.woocommerce-summary__item.is-selected .woocommerce-summary__item-value{font-weight:600}.woocommerce-summary__item.is-selected .woocommerce-summary__item-delta{font-weight:400}.woocommerce-summary__item.is-good-trend .woocommerce-summary__item-delta{background-color:#4ab866;color:#fff}.woocommerce-summary__item.is-bad-trend .woocommerce-summary__item-delta{background-color:#d94f4f;color:#fff}.woocommerce-summary__item .woocommerce-summary__toggle{position:absolute;top:44px;left:16px;transition:transform ease .2s}@media screen and (prefers-reduced-motion: reduce){.woocommerce-summary__item .woocommerce-summary__toggle{transition:none}}.is-dropdown-expanded .woocommerce-summary__item .woocommerce-summary__toggle{transform:rotate(180deg)}.components-popover__content .woocommerce-summary__item .woocommerce-summary__item-label{margin-bottom:0}.components-popover__content .woocommerce-summary__item .woocommerce-summary__item-value,.components-popover__content .woocommerce-summary__item .woocommerce-summary__item-delta{margin-bottom:0}.woocommerce-table{margin-bottom:40px}.woocommerce-table .woocommerce-table__actions{display:inline-flex;justify-content:flex-end;align-items:center}.woocommerce-table .woocommerce-table__actions>*{margin-left:16px}.woocommerce-table .woocommerce-table__actions>*:last-child{margin-left:0}.woocommerce-table .woocommerce-table__actions>div{width:100%}.woocommerce-table .components-card__footer{flex-direction:column}.woocommerce-table .components-card__footer>*{padding-left:0}.woocommerce-table.is-empty{align-items:center;background:#f0f0f0;color:#757575;display:flex;height:calc(16px + 1.1375rem + 1px + (32px + 1.1375rem + 1px)*var(--number-of-rows));justify-content:center;padding:16px;text-align:center}.woocommerce-table .woocommerce-pagination{margin-bottom:16px;z-index:1;background:#fff;position:relative}.woocommerce-table .components-card__header{align-items:center;text-align:right;display:grid;width:100%;grid-template-columns:auto 1fr auto}@media(max-width: 960px){.woocommerce-table.has-search .woocommerce-table__actions{grid-gap:12px;grid-template-columns:auto 1fr;grid-row-start:2;grid-row-end:2;grid-column-start:1;grid-column-end:4;margin:0}}.woocommerce-table .woocommerce-search .woocommerce-select-control__control{height:38px}.woocommerce-table .woocommerce-compare-button{padding:3px 12px;height:auto}.woocommerce-table .woocommerce-ellipsis-menu{justify-content:flex-end;display:flex}.woocommerce-table__preface{margin:12px 16px 12px 16px}.woocommerce-table__caption{font-size:24px;font-size:1.5rem;text-align:right}.components-card__body{position:relative}.woocommerce-table__table{overflow-x:auto}.woocommerce-table__table::after,.woocommerce-table__table::before{content:"";position:absolute;top:0;width:60px;height:100%;opacity:0;pointer-events:none;transition:opacity .3s;z-index:1}.woocommerce-table__table::after{left:0;background:linear-gradient(-90deg, rgba(255, 255, 255, 0), #fff)}.woocommerce-table__table::before{right:0;background:linear-gradient(-90deg, #fff, rgba(255, 255, 255, 0))}.woocommerce-table__table.is-scrollable-right::after,.woocommerce-table__table.is-scrollable-left::before{opacity:1}.woocommerce-table__table table{border-collapse:collapse;width:100%}.woocommerce-table__table tr:hover,.woocommerce-table__table tr:focus-within{background-color:#e0e0e0}.woocommerce-table__table tr:hover td,.woocommerce-table__table tr:hover th,.woocommerce-table__table tr:focus-within td,.woocommerce-table__table tr:focus-within th{background:rgba(0,0,0,0)}.woocommerce-table__header,.woocommerce-table__item,.woocommerce-table__empty-item{padding:16px 24px}.woocommerce-table__header,.woocommerce-table__item{font-size:13px;font-size:0.8125rem;text-align:right;border-bottom:1px solid #e2e4e7}.woocommerce-table__header>a:only-child,.woocommerce-table__item>a:only-child{display:block}.woocommerce-table__header a:hover,.woocommerce-table__header a:focus,.woocommerce-table__item a:hover,.woocommerce-table__item a:focus{color:#5007aa}.woocommerce-table__header .is-placeholder,.woocommerce-table__item .is-placeholder{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);display:inline-block;height:16px;max-width:120px;width:80%}.woocommerce-table__header .is-placeholder::after,.woocommerce-table__item .is-placeholder::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-table__header .is-placeholder,.woocommerce-table__item .is-placeholder{animation:none}}.woocommerce-table__header:not(.is-left-aligned),.woocommerce-table__item:not(.is-left-aligned){text-align:left}.woocommerce-table__header:not(.is-left-aligned) button,.woocommerce-table__item:not(.is-left-aligned) button{justify-content:flex-end;padding-left:24px;padding-right:24px}.woocommerce-table__header.is-numeric .is-placeholder,.woocommerce-table__item.is-numeric .is-placeholder{max-width:40px}.woocommerce-table__header .is-negative,.woocommerce-table__item .is-negative{color:#d94f4f;font-weight:bold}.woocommerce-table__header.is-sorted,.woocommerce-table__item.is-sorted{background-color:#f0f0f0}.woocommerce-table__header.is-checkbox-column,.woocommerce-table__item.is-checkbox-column{width:33px;max-width:33px;padding-left:0;padding-right:16px}.woocommerce-table__header.is-checkbox-column+th,.woocommerce-table__item.is-checkbox-column+th{border-right:0}.woocommerce-table tr:last-child .woocommerce-table__item{border-bottom:0}.woocommerce-table__empty-item{text-align:center;font-size:18px;font-size:1.125rem;color:#757575;font-weight:bold}@media(max-width: 782px){.woocommerce-table__empty-item{font-size:13px;font-size:0.8125rem}}th.woocommerce-table__item{font-weight:normal}.woocommerce-table__header{padding:8px 24px;background-color:#f8f9fa;font-weight:bold;white-space:nowrap}.woocommerce-table__header.is-left-aligned.is-sortable{padding-right:16px}.woocommerce-table__header.is-left-aligned.is-sortable svg{display:inline-flex;order:1;margin-right:0}.woocommerce-table__header .components-button.is-button{height:auto;width:100%;padding:8px 0 8px 24px;vertical-align:middle;line-height:1;border:none;background:rgba(0,0,0,0) !important;box-shadow:none !important;align-items:center}.woocommerce-table__header .components-button.is-button:hover{box-shadow:none !important}.woocommerce-table__header .components-button.is-button:active{box-shadow:none !important}.woocommerce-table__header.is-sortable{padding:0}.woocommerce-table__header.is-sortable svg{visibility:hidden;margin-right:4px}.woocommerce-table__header.is-sortable.is-sorted .components-button svg,.woocommerce-table__header.is-sortable .components-button:hover svg,.woocommerce-table__header.is-sortable .components-button:focus svg{visibility:visible}.woocommerce-table__summary{text-align:center;margin:0}.woocommerce-table__summary-item{display:inline-block;margin-bottom:0;margin-right:8px;margin-left:8px}.woocommerce-table__summary-item .is-placeholder{animation:loading-fade 1.6s ease-in-out infinite;background-color:#f0f0f0;color:rgba(0,0,0,0);display:inline-block;height:16px;width:200px}.woocommerce-table__summary-item .is-placeholder::after{content:" "}@media screen and (prefers-reduced-motion: reduce){.woocommerce-table__summary-item .is-placeholder{animation:none}}.woocommerce-table__summary-item .woocommerce-table__summary-label,.woocommerce-table__summary-item .woocommerce-table__summary-value{display:inline-block}.woocommerce-table__summary-item .woocommerce-table__summary-label{margin-right:4px}.woocommerce-table__summary-item .woocommerce-table__summary-value{font-weight:600}.woocommerce-tag{display:inline-flex;margin:1px 0 1px 4px;overflow:hidden;vertical-align:middle}.woocommerce-tag .woocommerce-tag__text,.woocommerce-tag .woocommerce-tag__remove{display:inline-block;font-size:12px;line-height:24px;background:#f0f0f0;transition:all .2s cubic-bezier(0.4, 1, 0.4, 1)}.woocommerce-tag .woocommerce-tag__text{align-self:center;padding:0 8px;border-radius:2px;color:#1e1e1e;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.woocommerce-tag.has-remove .woocommerce-tag__text{padding:0 8px 0 2px;border-radius:0 2px 2px 0}.woocommerce-tag .woocommerce-tag__remove{cursor:pointer;height:inherit;padding:0 0 0 5px;border-radius:2px 0 0 2px;color:#757575;line-height:10px;text-indent:0;display:flex;align-items:center}.woocommerce-tag .woocommerce-tag__remove:hover{color:#1e1e1e}.muriel-input-text{background:#fff;border:1px solid #a7aaad;border-radius:3px;height:56px;box-shadow:none;padding:12px 12px 4px;position:relative;box-shadow:0 1px 1px rgba(0,0,0,.03),0 1px 2px rgba(0,0,0,.02),0 3px 3px rgba(0,0,0,.02),0 4px 4px rgba(0,0,0,.01)}.muriel-input-text:hover{border-color:#787c82}.muriel-input-text label{color:#646970;font-size:14px;line-height:21px}.muriel-input-text label.components-base-control__label{margin:0}.muriel-input-text .components-text-control__input,.muriel-input-text .components-text-control__input[type=text],.muriel-input-text .components-text-control__input[type=tel],.muriel-input-text .components-text-control__input[type=time],.muriel-input-text .components-text-control__input[type=url],.muriel-input-text .components-text-control__input[type=week],.muriel-input-text .components-text-control__input[type=password],.muriel-input-text .components-text-control__input[type=color],.muriel-input-text .components-text-control__input[type=date],.muriel-input-text .components-text-control__input[type=datetime],.muriel-input-text .components-text-control__input[type=datetime-local],.muriel-input-text .components-text-control__input[type=email],.muriel-input-text .components-text-control__input[type=month],.muriel-input-text .components-text-control__input[type=number]{border:0;box-shadow:none;font-size:16px;line-height:21px;margin:0;padding:0;min-height:30px}.muriel-input-text .components-text-control__input:focus,.muriel-input-text .components-text-control__input[type=text]:focus,.muriel-input-text .components-text-control__input[type=tel]:focus,.muriel-input-text .components-text-control__input[type=time]:focus,.muriel-input-text .components-text-control__input[type=url]:focus,.muriel-input-text .components-text-control__input[type=week]:focus,.muriel-input-text .components-text-control__input[type=password]:focus,.muriel-input-text .components-text-control__input[type=color]:focus,.muriel-input-text .components-text-control__input[type=date]:focus,.muriel-input-text .components-text-control__input[type=datetime]:focus,.muriel-input-text .components-text-control__input[type=datetime-local]:focus,.muriel-input-text .components-text-control__input[type=email]:focus,.muriel-input-text .components-text-control__input[type=month]:focus,.muriel-input-text .components-text-control__input[type=number]:focus{box-shadow:none}.muriel-input-text.active{box-shadow:0 0 0 2px var(--wp-admin-theme-color);border-color:rgba(0,0,0,0)}.muriel-input-text.active input{color:#2c3338}.muriel-input-text.with-value .components-base-control__label{display:block;position:relative;top:-8px;width:100%;font-size:12px}.muriel-input-text.with-value input{color:#2c3338;position:relative;top:-12px}.muriel-input-text.empty label{display:none}.muriel-input-text.empty input{color:#646970}.muriel-input-text.has-error{box-shadow:none}.muriel-input-text.disabled label{display:none}.muriel-input-text.disabled input{color:#a7aaad}.muriel-input-text.disabled input::-moz-placeholder{color:#a7aaad;opacity:1}.muriel-input-text.disabled input::placeholder{color:#a7aaad;opacity:1}.muriel-input-text.disabled input:-ms-input-placeholder{color:#a7aaad}.muriel-input-text.disabled input::-ms-input-placeholder{color:#a7aaad}.text-control-with-affixes{display:inline-flex;flex-direction:row;width:100%}.text-control-with-affixes input[type=email],.text-control-with-affixes input[type=password],.text-control-with-affixes input[type=url],.text-control-with-affixes input[type=text],.text-control-with-affixes input[type=number]{flex-grow:1;margin:0}.text-control-with-affixes input[type=email]:disabled,.text-control-with-affixes input[type=password]:disabled,.text-control-with-affixes input[type=url]:disabled,.text-control-with-affixes input[type=text]:disabled,.text-control-with-affixes input[type=number]:disabled{border-left-width:0}.text-control-with-affixes input[type=email]:disabled+.text-control-with-affixes__suffix,.text-control-with-affixes input[type=password]:disabled+.text-control-with-affixes__suffix,.text-control-with-affixes input[type=url]:disabled+.text-control-with-affixes__suffix,.text-control-with-affixes input[type=text]:disabled+.text-control-with-affixes__suffix,.text-control-with-affixes input[type=number]:disabled+.text-control-with-affixes__suffix{border-right:1px solid #f0f0f0}.text-control-with-affixes.text-control-with-prefix input{border-top-right-radius:0;border-bottom-right-radius:0}.text-control-with-affixes.text-control-with-suffix input{border-top-left-radius:0;border-bottom-left-radius:0}.text-control-with-affixes__prefix,.text-control-with-affixes__suffix{position:relative;background:#fff;border-width:1px;border-style:solid;border-color:#757575;color:#757575;padding:7px 14px;white-space:nowrap;flex:1 0 auto;font-size:14px;line-height:1.5}.disabled .text-control-with-affixes__prefix,.disabled .text-control-with-affixes__suffix{background:rgba(255,255,255,.5);border-color:rgba(222,222,222,.75);box-shadow:inset 0 1px 2px rgba(0,0,0,.04);color:rgba(51,51,51,.5)}.text-control-with-affixes__prefix{border-left:none;border-radius:0 4px 4px 0}.text-control-with-affixes__prefix+input[type=email]:disabled,.text-control-with-affixes__prefix+input[type=password]:disabled,.text-control-with-affixes__prefix+input[type=url]:disabled,.text-control-with-affixes__prefix+input[type=text]:disabled,.text-control-with-affixes__prefix+input[type=number]:disabled{border-right-color:#f0f0f0}.text-control-with-affixes__suffix{border-right:none;border-radius:4px 0 0 4px}.woocommerce-tooltip{display:inline-flex}.woocommerce-tooltip .woocommerce-tooltip__button{height:auto;padding:0}.woocommerce-tooltip__text .components-popover__content{font-size:13px;font-weight:normal;padding:16px;text-transform:none;width:auto;max-width:300px}.woocommerce-tooltip__text .components-popover__content a{white-space:nowrap;text-decoration:underline}.woocommerce-timeline ul{margin:0;padding-right:0;list-style-type:none}.woocommerce-timeline ul li{margin-bottom:0}.woocommerce-timeline .woocommerce-timeline-group .woocommerce-timeline-group__title{color:#1d2327;font-size:12px;font-weight:600;text-transform:uppercase;margin:0 0 16px 0;display:inline-block}.woocommerce-timeline .woocommerce-timeline-group hr{float:left;width:calc(100% - 40px);margin-bottom:16px;border:.5px solid #e3dfe2}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__top-border{min-height:16px;border-right:1px solid #c3c4c7;margin:0 12px}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__title{display:flex;align-items:center;flex-direction:row;justify-content:space-between;color:#2c3338}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__title *{font-size:16px}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__headline{display:flex;align-items:center;flex-direction:row;margin:8px 0}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__headline *{margin:0}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__headline>*{padding:0 16px}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__headline svg{fill:#fff;padding:4px;background:#c3c4c7;border-radius:9999px;box-sizing:content-box;width:16px;height:16px}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__headline svg.is-success{background:#4ab866}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__headline svg.is-warning{background:#ffb900}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__headline svg.is-error{background:#d94f4f}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__timestamp{font-size:14px;line-height:16px}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__body{display:flex;flex-direction:column;color:#50575e;margin:0 12px;padding:8px 36px;border-right:1px solid #c3c4c7}.woocommerce-timeline .woocommerce-timeline-item .woocommerce-timeline-item__body *{margin:0;font-size:14px}.woocommerce-timeline ul :last-child.woocommerce-timeline-group hr:last-child{display:none}.woocommerce-view-more-list{padding-right:4px;margin:0 4px 0 0;vertical-align:middle}.woocommerce-view-more-list__popover{margin:0;padding:16px;text-align:right}.woocommerce-view-more-list__popover__item{display:block;margin:16px 0}.woocommerce-view-more-list__popover__item:first-child{margin-top:0}.woocommerce-view-more-list__popover__item:last-child{margin-bottom:0}.woocommerce-web-preview{width:100%;display:flex;align-items:center;justify-content:center;background:#f6f7f7}.woocommerce-web-preview.is-loading .woocommerce-web-preview__iframe-wrapper{display:none}.woocommerce-web-preview .woocommerce-web-preview__iframe-wrapper{width:100%}.woocommerce-web-preview iframe{width:100%;height:100%;min-height:400px}.woocommerce-badge{background-color:#f0f0f0;border-radius:20px;display:inline-block;text-align:center;font-style:normal;font-weight:600;font-size:14px;line-height:27px;align-items:center;min-width:32px;height:28px;padding:0 6px}.woocommerce-component_dynamic-form .components-base-control{margin-top:16px;margin-bottom:16px;position:relative}.woocommerce-component_dynamic-form .components-base-control.has-error .components-base-control__help{right:0 !important}.woocommerce-tour-kit{box-shadow:0 0 8px rgba(0,0,0,.15);position:absolute;z-index:9999}.woocommerce-tour-kit .woocommerce-tour-kit-step{width:350px;padding-bottom:4px}.woocommerce-tour-kit .woocommerce-tour-kit-step__body{padding-top:0;padding-bottom:8px}.woocommerce-tour-kit .woocommerce-tour-kit-step__heading{color:#101517;font-weight:500;font-size:16px;margin:0;letter-spacing:-0.1px;line-height:24px}.woocommerce-tour-kit .woocommerce-tour-kit-step__description{color:#2c3338;font-style:normal;font-weight:400;font-size:14px;line-height:20px;letter-spacing:-0.24px;margin:4px 0 0}.woocommerce-tour-kit .components-card-header{padding-bottom:0}.woocommerce-tour-kit .woocommerce-tour-kit-step-controls__close-btn{height:16px;min-width:16px;padding:0;z-index:1}.woocommerce-tour-kit .woocommerce-tour-kit-step-controls__close-btn svg{fill:#1e1e1e}.woocommerce-tour-kit .woocommerce-tour-kit-step-navigation{display:flex;align-items:center;justify-content:space-between;width:100%}.woocommerce-tour-kit .woocommerce-tour-kit-step-navigation button{margin-right:16px}.woocommerce-tour-kit .woocommerce-tour-kit-step-navigation__step{color:#50575e;font-style:normal;font-weight:400;font-size:12px;line-height:20px}.woocommerce-tour-kit .tour-kit-frame__arrow,.woocommerce-tour-kit .tour-kit-frame__arrow::before{z-index:1}.woocommerce-collapsible-content .woocommerce-collapsible-content__toggle{all:unset;font-size:13px;color:#007cba;cursor:pointer;display:flex;align-items:center}.woocommerce-collapsible-content .woocommerce-collapsible-content__toggle svg{fill:#007cba;margin-right:2px}.woocommerce-collapsible-content .woocommerce-collapsible-content__content{margin-top:24px}.components-base-control .components-text-control__input,.components-base-control .components-input-control .components-input-control__container .components-input-control__input,.components-base-control .components-select-control .components-input-control__container .components-select-control__input{min-height:36px}.experimental-woocommerce-tree-item{margin:0}.experimental-woocommerce-tree-item--highlighted>.experimental-woocommerce-tree-item__heading{background-color:#f0f0f0;outline:1.5px solid var(--wp-admin-theme-color);outline-offset:-1.5px}.experimental-woocommerce-tree-item__heading{display:flex;flex-grow:1;gap:8px;min-height:40px;padding:0 calc((var(--level) - 1)*28px + 12px) 0 12px;border-radius:2px}.experimental-woocommerce-tree-item__heading:hover,.experimental-woocommerce-tree-item__heading:focus-within{outline:1.5px solid var(--wp-admin-theme-color);outline-offset:-1.5px}.experimental-woocommerce-tree-item__heading:hover,.experimental-woocommerce-tree-item__heading:focus-within{background-color:#f0f0f0}.experimental-woocommerce-tree-item__label{display:flex;flex-grow:1;align-items:center;padding:8px 0 8px 12px;position:relative}.experimental-woocommerce-tree-item__label>span{display:block}.experimental-woocommerce-tree-item__label svg.components-checkbox-control__checked,.experimental-woocommerce-tree-item__label svg.components-checkbox-control__indeterminate,.experimental-woocommerce-tree-item__label .components-checkbox-control__input[type=checkbox]{cursor:default}.experimental-woocommerce-tree-item__label svg.components-checkbox-control__checked:focus,.experimental-woocommerce-tree-item__label svg.components-checkbox-control__indeterminate:focus,.experimental-woocommerce-tree-item__label .components-checkbox-control__input[type=checkbox]:focus{outline:none;box-shadow:none}.experimental-woocommerce-tree-item__expander{display:flex;align-items:center}.experimental-woocommerce-tree-item__expander .components-button{cursor:default;padding:0;height:24px;width:24px;min-width:24px}.experimental-woocommerce-tree-item__checkbox{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0, 0, 0, 0);white-space:nowrap;border-width:0}.experimental-woocommerce-tree{list-style:none;padding:0;margin:0}.experimental-woocommerce-tree--level-1{max-height:280px;overflow-y:auto;background-color:#fff;border:1px solid #ccc;border-radius:2px}.experimental-woocommerce-tree__button{width:100%;cursor:default}.experimental-woocommerce-tree__button:hover,.experimental-woocommerce-tree__button:focus-within,.experimental-woocommerce-tree__button--highlighted{outline:1.5px solid var(--wp-admin-theme-color);outline-offset:-1.5px;background-color:#f0f0f0}.woocommerce-experimental-select-control__combo-box-wrapper:focus{box-shadow:0 0 0 1px var(--wp-admin-theme-color);border-color:var(--wp-admin-theme-color)}.woocommerce-experimental-select-control__input:disabled{background-color:#f0f0f0}.woocommerce-experimental-select-control__suffix,.woocommerce-experimental-select-control__suffix-items{display:flex;align-items:center}.woocommerce-experimental-select-control__suffix button,.woocommerce-experimental-select-control__suffix-items button{height:24px;padding:0 4px}.woocommerce-experimental-select-control__icon-clear{padding-left:0}.woocommerce-experimental-select-control__icon-clear svg{fill:#757575;cursor:pointer}.woocommerce-experimental-select-tree-control__dropdown{display:block}.woocommerce-experimental-select-tree-control__dropdown .experimental-woocommerce-tree.experimental-woocommerce-tree--level-1{border-top:none;border-left:none;border-right:none;border-radius:0}.woocommerce-experimental-select-tree-control__dropdown .experimental-woocommerce-tree-item__label{margin-bottom:0}.woocommerce-experimental-select-tree-control__dropdown-content .components-popover__content{padding:0}.woocommerce-experimental-select-tree-control__popover-menu{min-height:100px}.woocommerce-tree-select-control{position:relative}.woocommerce-tree-select-control__label{display:block;font-size:16px;color:#757575;padding-bottom:8px}.woocommerce-tree-select-control__help{margin-top:4px;line-height:16px;font-size:12px;color:#757575}.woocommerce-tree-select-control .components-base-control{height:auto;display:flex;flex-wrap:wrap;align-items:center;border:1px solid #949494;border-radius:3px;background:#fff;padding:12px;position:relative}.woocommerce-tree-select-control .components-base-control .components-base-control__field{display:flex;align-items:center;flex:1;flex-basis:content;margin-bottom:0;max-width:100%}.woocommerce-tree-select-control .components-base-control .woocommerce-tree-select-control__control-input{font-size:16px;border:0;box-shadow:none;color:#2f2f2f;margin:0;padding-right:0;padding-left:0;width:100%;line-height:24px;text-align:right;letter-spacing:inherit;background:rgba(0,0,0,0)}.woocommerce-tree-select-control .components-base-control .woocommerce-tree-select-control__control-input::-webkit-search-cancel-button{display:none}.woocommerce-tree-select-control .components-base-control .woocommerce-tree-select-control__control-input:focus{outline:none}.woocommerce-tree-select-control .components-base-control i{color:#636d75;margin-left:12px;width:24px}.woocommerce-tree-select-control .components-base-control.is-active{box-shadow:0 0 0 1px var(--wp-admin-theme-color);border-color:var(--wp-admin-theme-color)}.woocommerce-tree-select-control .components-base-control.with-value .components-base-control__label,.woocommerce-tree-select-control .components-base-control.has-tags .components-base-control__label{font-size:12px;margin-top:-12px}.woocommerce-tree-select-control .components-base-control.is-disabled{border:1px solid rgba(167,170,173,.5);background:rgba(255,255,255,.5)}.woocommerce-tree-select-control .components-base-control.is-disabled .components-base-control__field{visibility:hidden}.woocommerce-tree-select-control .components-base-control.is-disabled .components-base-control__label{cursor:default}.woocommerce-tree-select-control .components-base-control.is-disabled .woocommerce-tag__remove{cursor:default;pointer-events:none}.woocommerce-tree-select-control .woocommerce-tree-select-control__autofill-input{position:absolute;z-index:-1}.woocommerce-tree-select-control .woocommerce-tree-select-control__tags{position:relative;margin:0}.woocommerce-tree-select-control .woocommerce-tree-select-control__tags.has-clear{padding-left:24px}.woocommerce-tree-select-control .woocommerce-tree-select-control__show-more{max-height:24px}.woocommerce-tree-select-control .woocommerce-tag{max-height:24px}.woocommerce-tree-select-control .woocommerce-tree-select-control__clear{position:absolute;left:10px;top:calc(50% - 10px)}.woocommerce-tree-select-control .woocommerce-tree-select-control__clear>.clear-icon{color:#ccc}.woocommerce-tree-select-control .woocommerce-tree-select-control__tree{background:#fff;display:flex;flex-direction:column;align-items:stretch;box-shadow:0 3px 5px rgba(0,0,0,.2),0 1px 18px rgba(0,0,0,.12),0 6px 10px rgba(0,0,0,.14);border-radius:3px;position:absolute;right:0;left:0;z-index:10;overflow-y:auto;max-height:350px;padding:16px}.woocommerce-tree-select-control .woocommerce-tree-select-control__tree.is-static{position:static}.woocommerce-tree-select-control .woocommerce-tree-select-control__node.has-children{border-bottom:1px solid #eee}.woocommerce-tree-select-control .woocommerce-tree-select-control__node.has-children:last-child{border-bottom:0}.woocommerce-tree-select-control .woocommerce-tree-select-control__children{padding-right:calc(16px*2)}.woocommerce-tree-select-control .woocommerce-tree-select-control__main{border-top:1px solid #e0e0e0;padding-right:0}.woocommerce-tree-select-control .woocommerce-tree-select-control__option{font-size:16px;padding:0 8px 0 0;flex:1;text-align:right;border:none;min-height:0;display:flex;height:auto}.woocommerce-tree-select-control .woocommerce-tree-select-control__option.is-selected,.woocommerce-tree-select-control .woocommerce-tree-select-control__option:hover{color:var(--wp-admin-theme-color)}.woocommerce-tree-select-control .woocommerce-tree-select-control__option.is-partially-checked .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]{background:var(--wp-admin-theme-color);border:4px solid #fff;box-shadow:0 0 0 1px #1e1e1e}.woocommerce-tree-select-control .woocommerce-tree-select-control__option.is-partially-checked .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:focus{border-color:#fff;box-shadow:0 0 0 1px #fff,0 0 0 3px var(--wp-admin-theme-color)}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container{height:24px;width:24px;display:inline-block;margin-left:12px;position:relative;vertical-align:middle}@media(min-width: 600px){.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container{height:20px;width:20px}}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]{font-family:-apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,Oxygen-Sans,Ubuntu,Cantarell,"Helvetica Neue",sans-serif;padding:6px 8px;box-shadow:0 0 0 rgba(0,0,0,0);border-radius:2px;border:1px solid #949494;font-size:16px;line-height:normal;border:1px solid #1e1e1e;margin-left:12px;transition:none;border-radius:2px;background:#fff;color:#1e1e1e;clear:none;cursor:pointer;display:inline-block;line-height:0;margin:0 0 0 4px;outline:0;padding:0 !important;text-align:center;vertical-align:top;width:24px;height:24px;-webkit-appearance:none;-moz-appearance:none;appearance:none}@media not (prefers-reduced-motion){.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]{transition:box-shadow .1s linear}}@media(min-width: 600px){.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]{font-size:13px;line-height:normal}}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:focus{border-color:var(--wp-admin-theme-color);box-shadow:0 0 0 .5px var(--wp-admin-theme-color);outline:2px solid rgba(0,0,0,0)}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]::-webkit-input-placeholder{color:rgba(30,30,30,.62)}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]::-moz-placeholder{color:rgba(30,30,30,.62)}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:-ms-input-placeholder{color:rgba(30,30,30,.62)}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:focus{box-shadow:0 0 0 2px #fff,0 0 0 4px var(--wp-admin-theme-color);outline:2px solid rgba(0,0,0,0)}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:checked{background:var(--wp-admin-theme-color);border-color:var(--wp-admin-theme-color)}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:checked::-ms-check{opacity:0}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:checked::before,.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox][aria-checked=mixed]::before{margin:-3px -5px;color:#fff}@media(min-width: 782px){.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:checked::before,.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox][aria-checked=mixed]::before{margin:-4px -5px 0 0}}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox][aria-checked=mixed]{background:var(--wp-admin-theme-color);border-color:var(--wp-admin-theme-color)}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox][aria-checked=mixed]::before{content:"";float:right;display:inline-block;vertical-align:middle;width:16px;font:normal 30px/1 dashicons;speak:none;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}@media(min-width: 782px){.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox][aria-checked=mixed]::before{float:none;font-size:21px}}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox][aria-disabled=true],.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:disabled{background:#f0f0f0;border-color:#ddd;cursor:default;opacity:1}@media(min-width: 600px){.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]{height:20px;width:20px}}@media(prefers-reduced-motion: reduce){.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]{transition-duration:0s;transition-delay:0s}}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:checked,.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:indeterminate{background:var(--wp-components-color-accent, var(--wp-admin-theme-color, #3858e9));border-color:var(--wp-components-color-accent, var(--wp-admin-theme-color, #3858e9))}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:checked::-ms-check,.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:indeterminate::-ms-check{opacity:0}.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]:checked::before{content:none}@media(min-width: 600px){.woocommerce-tree-select-control .woocommerce-tree-select-control__option .components-checkbox-control__input-container .components-checkbox-control__input[type=checkbox]{height:20px;width:20px}}.woocommerce-tree-select-control .woocommerce-tree-select-control__expander{padding:4px;cursor:pointer;margin-left:0;background:rgba(0,0,0,0);border:none}.woocommerce-tree-select-control .woocommerce-tree-select-control__expander.is-hidden{visibility:hidden;pointer-events:none}.woocommerce-tree-select-control .components-checkbox-control__label{width:100%;display:flex;min-height:56px;align-items:center}.woocommerce-tree-select-control.is-searchable .components-base-control__label{right:48px}.woocommerce-tree-select-control.is-searchable .components-base-control.is-active .components-base-control__label{font-size:12px;margin-top:-12px}.woocommerce-tree-select-control.is-searchable .woocommerce-tree-select-control__control-input{padding-right:12px}.woocommerce-progress-bar__container{height:8px;width:100%}.woocommerce-progress-bar__filler{height:100%;min-width:8px}.wcpay-component-phone-number-input{display:inline-block;position:relative}.wcpay-component-phone-number-input__button{position:absolute;top:0;bottom:0;display:flex;align-items:center;padding-right:8px;padding-left:4px;background:none;border:none}.wcpay-component-phone-number-input__button-arrow{margin-top:2px}.wcpay-component-phone-number-input__button-arrow.invert{margin-top:0;transform:rotate(-180deg)}.wcpay-component-phone-number-input__input{font-size:inherit}.wcpay-component-phone-number-input__menu{position:absolute;max-height:200px;min-width:100%;background-color:#fff;border-radius:2px;border:1px solid #757575;margin:1px 0;z-index:10000;overflow-y:auto}.wcpay-component-phone-number-input__menu[aria-hidden=true]{display:none}.wcpay-component-phone-number-input__menu-item{padding:4px 8px;margin:0;display:flex;align-items:center}.wcpay-component-phone-number-input__menu-item.highlighted{background:#dcdcde}.wcpay-component-phone-number-input__flag{width:18px;margin-left:4px}.woocommerce-error-boundary{margin-block:16px}.woocommerce-error-boundary .woocommerce-empty-content__message{margin-block:12px}.woocommerce-error-boundary .woocommerce-empty-content{margin:0}.woocommerce-error-boundary .woocommerce-empty-content__illustration{margin-bottom:-7px}
